"""


File Operators
**************

:func:`autopack_toggle`

:func:`bookmark_add`

:func:`bookmark_cleanup`

:func:`bookmark_delete`

:func:`bookmark_move`

:func:`cancel`

:func:`delete`

:func:`directory_new`

:func:`edit_directory_path`

:func:`execute`

:func:`filenum`

:func:`filepath_drop`

:func:`find_missing_files`

:func:`hidedot`

:func:`highlight`

:func:`make_paths_absolute`

:func:`make_paths_relative`

:func:`mouse_execute`

:func:`next`

:func:`pack_all`

:func:`pack_libraries`

:func:`parent`

:func:`previous`

:func:`refresh`

:func:`rename`

:func:`report_missing_files`

:func:`reset_recent`

:func:`select`

:func:`select_all`

:func:`select_bookmark`

:func:`select_box`

:func:`select_walk`

:func:`smoothscroll`

:func:`sort_column_ui_context`

:func:`start_filter`

:func:`unpack_all`

:func:`unpack_item`

:func:`unpack_libraries`

:func:`view_selected`

"""

import typing

def autopack_toggle() -> None:

  """

  Automatically pack all external files into the .blend file

  """

  ...

def bookmark_add() -> None:

  """

  Add a bookmark for the selected/active directory

  """

  ...

def bookmark_cleanup() -> None:

  """

  Delete all invalid bookmarks

  """

  ...

def bookmark_delete(index: int = -1) -> None:

  """

  Delete selected bookmark

  """

  ...

def bookmark_move(direction: str = 'TOP') -> None:

  """

  Move the active bookmark up/down in the list

  """

  ...

def cancel() -> None:

  """

  Cancel loading of selected file

  """

  ...

def delete() -> None:

  """

  Move selected files to the trash or recycle bin

  """

  ...

def directory_new(directory: str = '', open: bool = False, confirm: bool = True) -> None:

  """

  Create a new directory

  """

  ...

def edit_directory_path() -> None:

  """

  Start editing directory field

  """

  ...

def execute() -> None:

  """

  Execute selected file

  """

  ...

def filenum(increment: int = 1) -> None:

  """

  Increment number in filename

  """

  ...

def filepath_drop(filepath: str = 'Path') -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

  ...

def find_missing_files(find_all: bool = False, directory: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = False, filter_blenlib: bool = False, filemode: int = 9, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Try to find missing external files

  """

  ...

def hidedot() -> None:

  """

  Toggle hide hidden dot files

  """

  ...

def highlight() -> None:

  """

  Highlight selected file(s)

  """

  ...

def make_paths_absolute() -> None:

  """

  Make all paths to external files absolute

  """

  ...

def make_paths_relative() -> None:

  """

  Make all paths to external files relative to current .blend

  """

  ...

def mouse_execute() -> None:

  """

  Perform the current execute action for the file under the cursor (e.g. open the file)

  """

  ...

def next() -> None:

  """

  Move to next folder

  """

  ...

def pack_all() -> None:

  """

  Pack all used external files into this .blend

  """

  ...

def pack_libraries() -> None:

  """

  Store all data-blocks linked from other .blend files in the current .blend file. Library references are preserved so the linked data-blocks can be unpacked again

  """

  ...

def parent() -> None:

  """

  Move to parent directory

  """

  ...

def previous() -> None:

  """

  Move to previous folder

  """

  ...

def refresh() -> None:

  """

  Refresh the file list

  """

  ...

def rename() -> None:

  """

  Rename file or file directory

  """

  ...

def report_missing_files() -> None:

  """

  Report all missing external files

  """

  ...

def reset_recent() -> None:

  """

  Reset recent files

  """

  ...

def select(wait_to_deselect_others: bool = False, mouse_x: int = 0, mouse_y: int = 0, extend: bool = False, fill: bool = False, open: bool = True, deselect_all: bool = False, only_activate_if_selected: bool = False, pass_through: bool = False) -> None:

  """

  Handle mouse clicks to select and activate items

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  Select or deselect all files

  """

  ...

def select_bookmark(dir: str = '') -> None:

  """

  Select a bookmarked directory

  """

  ...

def select_box(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Activate/select the file(s) contained in the border

  """

  ...

def select_walk(direction: str = 'UP', extend: bool = False, fill: bool = False) -> None:

  """

  Select/Deselect files by walking through them

  """

  ...

def smoothscroll() -> None:

  """

  Smooth scroll to make editable file visible

  """

  ...

def sort_column_ui_context() -> None:

  """

  Change sorting to use column under cursor

  """

  ...

def start_filter() -> None:

  """

  Start entering filter text

  """

  ...

def unpack_all(method: str = 'USE_LOCAL') -> None:

  """

  Unpack all files packed into this .blend to external ones

  """

  ...

def unpack_item(method: str = 'USE_LOCAL', id_name: str = '', id_type: int = 19785) -> None:

  """

  Unpack this file to an external file

  """

  ...

def unpack_libraries() -> None:

  """

  Restore all packed linked data-blocks to their original locations

  """

  ...

def view_selected() -> None:

  """

  Scroll the selected files into view

  """

  ...



"""


Object Greasepencil Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. _rna-enum-object-greasepencil-modifier-type-items:

**Modify**

:GP_TEXTURE:      
  Texture Mapping.

  Change stroke uv texture values.

:GP_TIME:         
  Time Offset.

  Offset keyframes.

:GP_WEIGHT_ANGLE: 
  Vertex Weight Angle.

  Generate Vertex Weights base on stroke angle.

:GP_WEIGHT_PROXIMITY:
  Vertex Weight Proximity.

  Generate Vertex Weights base on distance to object.

**Generate**

:GP_ARRAY:        
  Array.

  Create array of duplicate instances.

:GP_BUILD:        
  Build.

  Create duplication of strokes.

:GP_DASH:         
  Dot Dash.

  Generate dot-dash styled strokes.

:GP_ENVELOPE:     
  Envelope.

  Create an envelope shape.

:GP_LENGTH:       
  Length.

  Extend or shrink strokes.

:GP_LINEART:      
  Line Art.

  Generate line art strokes from selected source.

:GP_MIRROR:       
  Mirror.

  Duplicate strokes like a mirror.

:GP_MULTIPLY:     
  Multiple Strokes.

  Produce multiple strokes along one stroke.

:GP_OUTLINE:      
  Outline.

  Convert stroke to perimeter.

:GP_SIMPLIFY:     
  Simplify.

  Simplify stroke reducing number of points.

:GP_SUBDIV:       
  Subdivide.

  Subdivide stroke adding more control points.

**Deform**

:GP_ARMATURE:     
  Armature.

  Deform stroke points using armature object.

:GP_HOOK:         
  Hook.

  Deform stroke points using objects.

:GP_LATTICE:      
  Lattice.

  Deform strokes using lattice.

:GP_NOISE:        
  Noise.

  Add noise to strokes.

:GP_OFFSET:       
  Offset.

  Change stroke location, rotation or scale.

:SHRINKWRAP:      
  Shrinkwrap.

  Project the shape onto another object.

:GP_SMOOTH:       
  Smooth.

  Smooth stroke.

:GP_THICK:        
  Thickness.

  Change stroke thickness.

**Color**

:GP_COLOR:        
  Hue/Saturation.

  Apply changes to stroke colors.

:GP_OPACITY:      
  Opacity.

  Opacity of the strokes.

:GP_TINT:         
  Tint.

  Tint strokes with new color.

"""

import typing



"""


Shrinkwrap Type Items
^^^^^^^^^^^^^^^^^^^^^

:NEAREST_SURFACEPOINT:
  Nearest Surface Point.

  Shrink the mesh to the nearest target surface.

:PROJECT:         
  Project.

  Shrink the mesh to the nearest target surface along a given axis.

:NEAREST_VERTEX:  
  Nearest Vertex.

  Shrink the mesh to the nearest target vertex.

:TARGET_PROJECT:  
  Target Normal Project.

  Shrink the mesh to the nearest target surface along the interpolated vertex normals of the target.

.. _rna-enum-shrinkwrap-type-items:

"""

import typing



"""


Object Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. _rna-enum-object-modifier-type-items:

**Modify**

:DATA_TRANSFER:   
  Data Transfer.

  Transfer several types of data (vertex groups, UV maps, vertex colors, custom normals) from one mesh to another.

:MESH_CACHE:      
  Mesh Cache.

  Deform the mesh using an external frame-by-frame vertex transform cache.

:MESH_SEQUENCE_CACHE:
  Mesh Sequence Cache.

  Deform the mesh or curve using an external mesh cache in Alembic format.

:NORMAL_EDIT:     
  Normal Edit.

  Modify the direction of the surface normals.

:WEIGHTED_NORMAL: 
  Weighted Normal.

  Modify the direction of the surface normals using a weighting method.

:UV_PROJECT:      
  UV Project.

  Project the UV map coordinates from the negative Z axis of another object.

:UV_WARP:         
  UV Warp.

  Transform the UV map using the difference between two objects.

:VERTEX_WEIGHT_EDIT:
  Vertex Weight Edit.

  Modify of the weights of a vertex group.

:VERTEX_WEIGHT_MIX:
  Vertex Weight Mix.

  Mix the weights of two vertex groups.

:VERTEX_WEIGHT_PROXIMITY:
  Vertex Weight Proximity.

  Set the vertex group weights based on the distance to another target object.

**Generate**

:ARRAY:           
  Array.

  Create copies of the shape with offsets.

:BEVEL:           
  Bevel.

  Generate sloped corners by adding geometry to the mesh's edges or vertices.

:BOOLEAN:         
  Boolean.

  Use another shape to cut, combine or perform a difference operation.

:BUILD:           
  Build.

  Cause the faces of the mesh object to appear or disappear one after the other over time.

:DECIMATE:        
  Decimate.

  Reduce the geometry density.

:EDGE_SPLIT:      
  Edge Split.

  Split away joined faces at the edges.

:NODES:           
  Geometry Nodes.

:MASK:            
  Mask.

  Dynamically hide vertices based on a vertex group or armature.

:MIRROR:          
  Mirror.

  Mirror along the local X, Y and/or Z axes, over the object origin.

:MESH_TO_VOLUME:  
  Mesh to Volume.

:MULTIRES:        
  Multiresolution.

  Subdivide the mesh in a way that allows editing the higher subdivision levels.

:REMESH:          
  Remesh.

  Generate new mesh topology based on the current shape.

:SCREW:           
  Screw.

  Lathe around an axis, treating the input mesh as a profile.

:SKIN:            
  Skin.

  Create a solid shape from vertices and edges, using the vertex radius to define the thickness.

:SOLIDIFY:        
  Solidify.

  Make the surface thick.

:SUBSURF:         
  Subdivision Surface.

  Split the faces into smaller parts, giving it a smoother appearance.

:TRIANGULATE:     
  Triangulate.

  Convert all polygons to triangles.

:VOLUME_TO_MESH:  
  Volume to Mesh.

:WELD:            
  Weld.

  Find groups of vertices closer than dist and merge them together.

:WIREFRAME:       
  Wireframe.

  Convert faces into thickened edges.

**Deform**

:ARMATURE:        
  Armature.

  Deform the shape using an armature object.

:CAST:            
  Cast.

  Shift the shape towards a predefined primitive.

:CURVE:           
  Curve.

  Bend the mesh using a curve object.

:DISPLACE:        
  Displace.

  Offset vertices based on a texture.

:HOOK:            
  Hook.

  Deform specific points using another object.

:LAPLACIANDEFORM: 
  Laplacian Deform.

  Deform based a series of anchor points.

:LATTICE:         
  Lattice.

  Deform using the shape of a lattice object.

:MESH_DEFORM:     
  Mesh Deform.

  Deform using a different mesh, which acts as a deformation cage.

:SHRINKWRAP:      
  Shrinkwrap.

  Project the shape onto another object.

:SIMPLE_DEFORM:   
  Simple Deform.

  Deform the shape by twisting, bending, tapering or stretching.

:SMOOTH:          
  Smooth.

  Smooth the mesh by flattening the angles between adjacent faces.

:CORRECTIVE_SMOOTH:
  Smooth Corrective.

  Smooth the mesh while still preserving the volume.

:LAPLACIANSMOOTH: 
  Smooth Laplacian.

  Reduce the noise on a mesh surface with minimal changes to its shape.

:SURFACE_DEFORM:  
  Surface Deform.

  Transfer motion from another mesh.

:WARP:            
  Warp.

  Warp parts of a mesh to a new location in a very flexible way thanks to 2 specified objects.

:WAVE:            
  Wave.

  Adds a ripple-like motion to an object's geometry.

:VOLUME_DISPLACE: 
  Volume Displace.

  Deform volume based on noise or other vector fields.

**Physics**

:CLOTH:           
  Cloth.

:COLLISION:       
  Collision.

:DYNAMIC_PAINT:   
  Dynamic Paint.

:EXPLODE:         
  Explode.

  Break apart the mesh faces and let them follow particles.

:FLUID:           
  Fluid.

:OCEAN:           
  Ocean.

  Generate a moving ocean surface.

:PARTICLE_INSTANCE:
  Particle Instance.

:PARTICLE_SYSTEM: 
  Particle System.

  Spawn particles from the shape.

:SOFT_BODY:       
  Soft Body.

:SURFACE:         
  Surface.

"""

import typing



"""


Property Flag Items
^^^^^^^^^^^^^^^^^^^

:HIDDEN:          
  Hidden.

:SKIP_SAVE:       
  Skip Save.

:ANIMATABLE:      
  Animatable.

:LIBRARY_EDITABLE:
  Library Editable.

:PROPORTIONAL:    
  Adjust values proportionally to each other.

:TEXTEDIT_UPDATE: 
  Update on every keystroke in textedit 'mode'.

:OUTPUT_PATH:     
  Output Path.

.. _rna-enum-property-flag-items:

"""

import typing



"""


Brush Gpencil Vertex Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

:BLUR:            
  Blur.

:AVERAGE:         
  Average.

:SMEAR:           
  Smear.

:REPLACE:         
  Replace.

.. _rna-enum-brush-gpencil-vertex-types-items:

"""

import typing



"""


Particle Operators
******************

:func:`brush_edit`

:func:`connect_hair`

:func:`copy_particle_systems`

:func:`delete`

:func:`disconnect_hair`

:func:`duplicate_particle_system`

:func:`dupliob_copy`

:func:`dupliob_move_down`

:func:`dupliob_move_up`

:func:`dupliob_refresh`

:func:`dupliob_remove`

:func:`edited_clear`

:func:`hair_dynamics_preset_add`

:func:`hide`

:func:`mirror`

:func:`new`

:func:`new_target`

:func:`particle_edit_toggle`

:func:`rekey`

:func:`remove_doubles`

:func:`reveal`

:func:`select_all`

:func:`select_less`

:func:`select_linked`

:func:`select_linked_pick`

:func:`select_more`

:func:`select_random`

:func:`select_roots`

:func:`select_tips`

:func:`shape_cut`

:func:`subdivide`

:func:`target_move_down`

:func:`target_move_up`

:func:`target_remove`

:func:`unify_length`

:func:`weight_set`

"""

import typing

def brush_edit(stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None) -> None:

  """

  Apply a stroke of brush to the particles

  """

  ...

def connect_hair(all: bool = False) -> None:

  """

  Connect hair to the emitter mesh

  """

  ...

def copy_particle_systems(space: str = 'OBJECT', remove_target_particles: bool = True, use_active: bool = False) -> None:

  """

  Copy particle systems from the active object to selected objects

  """

  ...

def delete(type: str = 'PARTICLE') -> None:

  """

  Delete selected particles or keys

  """

  ...

def disconnect_hair(all: bool = False) -> None:

  """

  Disconnect hair from the emitter mesh

  """

  ...

def duplicate_particle_system(use_duplicate_settings: bool = False) -> None:

  """

  Duplicate particle system within the active object

  """

  ...

def dupliob_copy() -> None:

  """

  Duplicate the current instance object

  """

  ...

def dupliob_move_down() -> None:

  """

  Move instance object down in the list

  """

  ...

def dupliob_move_up() -> None:

  """

  Move instance object up in the list

  """

  ...

def dupliob_refresh() -> None:

  """

  Refresh list of instance objects and their weights

  """

  ...

def dupliob_remove() -> None:

  """

  Remove the selected instance object

  """

  ...

def edited_clear() -> None:

  """

  Undo all edition performed on the particle system

  """

  ...

def hair_dynamics_preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Hair Dynamics Preset

  """

  ...

def hide(unselected: bool = False) -> None:

  """

  Hide selected particles

  """

  ...

def mirror() -> None:

  """

  Duplicate and mirror the selected particles along the local X axis

  """

  ...

def new() -> None:

  """

  Add new particle settings

  """

  ...

def new_target() -> None:

  """

  Add a new particle target

  """

  ...

def particle_edit_toggle() -> None:

  """

  Toggle particle edit mode

  """

  ...

def rekey(keys_number: int = 2) -> None:

  """

  Change the number of keys of selected particles (root and tip keys included)

  """

  ...

def remove_doubles(threshold: float = 0.0002) -> None:

  """

  Remove selected particles close enough of others

  """

  ...

def reveal(select: bool = True) -> None:

  """

  Show hidden particles

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  (De)select all particles' keys

  """

  ...

def select_less() -> None:

  """

  Deselect boundary selected keys of each particle

  """

  ...

def select_linked() -> None:

  """

  Select all keys linked to already selected ones

  """

  ...

def select_linked_pick(deselect: bool = False, location: typing.Tuple[int, int] = (0, 0)) -> None:

  """

  Select nearest particle from mouse pointer

  """

  ...

def select_more() -> None:

  """

  Select keys linked to boundary selected keys of each particle

  """

  ...

def select_random(ratio: float = 0.5, seed: int = 0, action: str = 'SELECT', type: str = 'HAIR') -> None:

  """

  Select a randomly distributed set of hair or points

  """

  ...

def select_roots(action: str = 'SELECT') -> None:

  """

  Select roots of all visible particles

  """

  ...

def select_tips(action: str = 'SELECT') -> None:

  """

  Select tips of all visible particles

  """

  ...

def shape_cut() -> None:

  """

  Cut hair to conform to the set shape object

  """

  ...

def subdivide() -> None:

  """

  Subdivide selected particles segments (adds keys)

  """

  ...

def target_move_down() -> None:

  """

  Move particle target down in the list

  """

  ...

def target_move_up() -> None:

  """

  Move particle target up in the list

  """

  ...

def target_remove() -> None:

  """

  Remove the selected particle target

  """

  ...

def unify_length() -> None:

  """

  Make selected hair the same length

  """

  ...

def weight_set(factor: float = 1.0) -> None:

  """

  Set the weight of selected keys

  """

  ...



"""


Wm Operators
************

:func:`append`

:func:`batch_rename`

:func:`blend_strings_utf8_validate`

:func:`call_menu`

:func:`call_menu_pie`

:func:`call_panel`

:func:`context_collection_boolean_set`

:func:`context_cycle_array`

:func:`context_cycle_enum`

:func:`context_cycle_int`

:func:`context_menu_enum`

:func:`context_modal_mouse`

:func:`context_pie_enum`

:func:`context_scale_float`

:func:`context_scale_int`

:func:`context_set_boolean`

:func:`context_set_enum`

:func:`context_set_float`

:func:`context_set_id`

:func:`context_set_int`

:func:`context_set_string`

:func:`context_set_value`

:func:`context_toggle`

:func:`context_toggle_enum`

:func:`debug_menu`

:func:`doc_view`

:func:`doc_view_manual`

:func:`doc_view_manual_ui_context`

:func:`drop_blend_file`

:func:`gpencil_import_svg`

:func:`interface_theme_preset_add`

:func:`keyconfig_preset_add`

:func:`lib_reload`

:func:`lib_relocate`

:func:`link`

:func:`memory_statistics`

:func:`obj_export`

:func:`obj_import`

:func:`open_mainfile`

:func:`operator_cheat_sheet`

:func:`operator_defaults`

:func:`operator_pie_enum`

:func:`operator_preset_add`

:func:`owner_disable`

:func:`owner_enable`

:func:`path_open`

:func:`previews_batch_clear`

:func:`previews_batch_generate`

:func:`previews_clear`

:func:`previews_ensure`

:func:`properties_add`

:func:`properties_context_change`

:func:`properties_edit`

:func:`properties_edit_value`

:func:`properties_remove`

:func:`quit_blender`

:func:`radial_control`

:func:`read_factory_settings`

:func:`read_factory_userpref`

:func:`read_history`

:func:`read_homefile`

:func:`read_userpref`

:func:`recover_auto_save`

:func:`recover_last_session`

:func:`redraw_timer`

:func:`revert_mainfile`

:func:`save_as_mainfile`

:func:`save_homefile`

:func:`save_mainfile`

:func:`save_userpref`

:func:`search_menu`

:func:`search_operator`

:func:`set_stereo_3d`

:func:`splash`

:func:`splash_about`

:func:`stl_import`

:func:`sysinfo`

:func:`tool_set_by_id`

:func:`tool_set_by_index`

:func:`toolbar`

:func:`toolbar_fallback_pie`

:func:`toolbar_prompt`

:func:`url_open`

:func:`url_open_preset`

:func:`window_close`

:func:`window_fullscreen_toggle`

:func:`window_new`

:func:`window_new_main`

"""

import typing

def append(filepath: str = '', directory: str = '', filename: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, check_existing: bool = False, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = True, filemode: int = 1, display_type: str = 'DEFAULT', sort_method: str = '', link: bool = False, do_reuse_local_id: bool = False, autoselect: bool = True, active_collection: bool = True, instance_collections: bool = False, instance_object_data: bool = True, set_fake: bool = False, use_recursive: bool = True) -> None:

  """

  Append from a Library .blend file

  """

  ...

def batch_rename(data_type: str = 'OBJECT', data_source: str = 'SELECT', actions: typing.Union[typing.Sequence[BatchRenameAction], typing.Mapping[str, BatchRenameAction], bpy.types.bpy_prop_collection] = None) -> None:

  """

  Rename multiple items at once

  """

  ...

def blend_strings_utf8_validate() -> None:

  """

  Check and fix all strings in current .blend file to be valid UTF-8 Unicode (needed for some old, 2.4x area files)

  """

  ...

def call_menu(name: str = '') -> None:

  """

  Open a predefined menu

  """

  ...

def call_menu_pie(name: str = '') -> None:

  """

  Open a predefined pie menu

  """

  ...

def call_panel(name: str = '', keep_open: bool = True) -> None:

  """

  Open a predefined panel

  """

  ...

def context_collection_boolean_set(data_path_iter: str = '', data_path_item: str = '', type: str = 'TOGGLE') -> None:

  """

  Set boolean values for a collection of items

  """

  ...

def context_cycle_array(data_path: str = '', reverse: bool = False) -> None:

  """

  Set a context array value (useful for cycling the active mesh edit mode)

  """

  ...

def context_cycle_enum(data_path: str = '', reverse: bool = False, wrap: bool = False) -> None:

  """

  Toggle a context value

  """

  ...

def context_cycle_int(data_path: str = '', reverse: bool = False, wrap: bool = False) -> None:

  """

  Set a context value (useful for cycling active material, vertex keys, groups, etc.)

  """

  ...

def context_menu_enum(data_path: str = '') -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

  ...

def context_modal_mouse(data_path_iter: str = '', data_path_item: str = '', header_text: str = '', input_scale: float = 0.01, invert: bool = False, initial_x: int = 0) -> None:

  """

  Adjust arbitrary values with mouse input

  """

  ...

def context_pie_enum(data_path: str = '') -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

  ...

def context_scale_float(data_path: str = '', value: float = 1.0) -> None:

  """

  Scale a float context value

  """

  ...

def context_scale_int(data_path: str = '', value: float = 1.0, always_step: bool = True) -> None:

  """

  Scale an int context value

  """

  ...

def context_set_boolean(data_path: str = '', value: bool = True) -> None:

  """

  Set a context value

  """

  ...

def context_set_enum(data_path: str = '', value: str = '') -> None:

  """

  Set a context value

  """

  ...

def context_set_float(data_path: str = '', value: float = 0.0, relative: bool = False) -> None:

  """

  Set a context value

  """

  ...

def context_set_id(data_path: str = '', value: str = '') -> None:

  """

  Set a context value to an ID data-block

  """

  ...

def context_set_int(data_path: str = '', value: int = 0, relative: bool = False) -> None:

  """

  Set a context value

  """

  ...

def context_set_string(data_path: str = '', value: str = '') -> None:

  """

  Set a context value

  """

  ...

def context_set_value(data_path: str = '', value: str = '') -> None:

  """

  Set a context value

  """

  ...

def context_toggle(data_path: str = '', module: str = '') -> None:

  """

  Toggle a context value

  """

  ...

def context_toggle_enum(data_path: str = '', value_1: str = '', value_2: str = '') -> None:

  """

  Toggle a context value

  """

  ...

def debug_menu(debug_value: int = 0) -> None:

  """

  Open a popup to set the debug level

  """

  ...

def doc_view(doc_id: str = '') -> None:

  """

  Open online reference docs in a web browser

  """

  ...

def doc_view_manual(doc_id: str = '') -> None:

  """

  Load online manual

  """

  ...

def doc_view_manual_ui_context() -> None:

  """

  View a context based online manual in a web browser

  """

  ...

def drop_blend_file(filepath: str = '') -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

  ...

def gpencil_import_svg(filepath: str = '', directory: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = True, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, relative_path: bool = True, display_type: str = 'DEFAULT', sort_method: str = '', resolution: int = 10, scale: float = 10.0) -> None:

  """

  Import SVG into grease pencil

  """

  ...

def interface_theme_preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a theme preset

  """

  ...

def keyconfig_preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Key-config Preset

  """

  ...

def lib_reload(library: str = '', filepath: str = '', directory: str = '', filename: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, relative_path: bool = True, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Reload the given library

  """

  ...

def lib_relocate(library: str = '', filepath: str = '', directory: str = '', filename: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, relative_path: bool = True, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Relocate the given library to one or several others

  """

  ...

def link(filepath: str = '', directory: str = '', filename: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, check_existing: bool = False, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = True, filemode: int = 1, relative_path: bool = True, display_type: str = 'DEFAULT', sort_method: str = '', link: bool = True, do_reuse_local_id: bool = False, autoselect: bool = True, active_collection: bool = True, instance_collections: bool = True, instance_object_data: bool = True) -> None:

  """

  Link from a Library .blend file

  """

  ...

def memory_statistics() -> None:

  """

  Print memory statistics to the console

  """

  ...

def obj_export(filepath: str = '', check_existing: bool = True, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'DEFAULT', sort_method: str = '', export_animation: bool = False, start_frame: int = -2147483648, end_frame: int = 2147483647, forward_axis: str = 'NEGATIVE_Z', up_axis: str = 'Y', global_scale: float = 1.0, apply_modifiers: bool = True, export_eval_mode: str = 'DAG_EVAL_VIEWPORT', export_selected_objects: bool = False, export_uv: bool = True, export_normals: bool = True, export_colors: bool = False, export_materials: bool = True, export_pbr_extensions: bool = False, path_mode: str = 'AUTO', export_triangulated_mesh: bool = False, export_curves_as_nurbs: bool = False, export_object_groups: bool = False, export_material_groups: bool = False, export_vertex_groups: bool = False, export_smooth_groups: bool = False, smooth_group_bitflags: bool = False, filter_glob: str = '*args.obj;*args.mtl') -> None:

  """

  Save the scene to a Wavefront OBJ file

  """

  ...

def obj_import(filepath: str = '', directory: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'DEFAULT', sort_method: str = '', global_scale: float = 1.0, clamp_size: float = 0.0, forward_axis: str = 'NEGATIVE_Z', up_axis: str = 'Y', use_split_objects: bool = True, use_split_groups: bool = False, import_vertex_groups: bool = False, validate_meshes: bool = False, filter_glob: str = '*args.obj;*args.mtl') -> None:

  """

  Load a Wavefront OBJ scene

  """

  ...

def open_mainfile(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'DEFAULT', sort_method: str = '', load_ui: bool = True, use_scripts: bool = True, display_file_selector: bool = True, state: int = 0) -> None:

  """

  Open a Blender file

  """

  ...

def operator_cheat_sheet() -> None:

  """

  List all the operators in a text-block, useful for scripting

  """

  ...

def operator_defaults() -> None:

  """

  Set the active operator to its default values

  """

  ...

def operator_pie_enum(data_path: str = '', prop_string: str = '') -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

  ...

def operator_preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False, operator: str = '') -> None:

  """

  Add or remove an Operator Preset

  """

  ...

def owner_disable(owner_id: str = '') -> None:

  """

  Disable add-on for workspace

  """

  ...

def owner_enable(owner_id: str = '') -> None:

  """

  Enable add-on for workspace

  """

  ...

def path_open(filepath: str = '') -> None:

  """

  Open a path in a file browser

  """

  ...

def previews_batch_clear(files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, directory: str = '', filter_blender: bool = True, filter_folder: bool = True, use_scenes: bool = True, use_collections: bool = True, use_objects: bool = True, use_intern_data: bool = True, use_trusted: bool = False, use_backups: bool = True) -> None:

  """

  Clear selected .blend file's previews

  """

  ...

def previews_batch_generate(files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, directory: str = '', filter_blender: bool = True, filter_folder: bool = True, use_scenes: bool = True, use_collections: bool = True, use_objects: bool = True, use_intern_data: bool = True, use_trusted: bool = False, use_backups: bool = True) -> None:

  """

  Generate selected .blend file's previews

  """

  ...

def previews_clear(id_type: typing.Set[str] = {}) -> None:

  """

  Clear data-block previews (only for some types like objects, materials, textures, etc.)

  """

  ...

def previews_ensure() -> None:

  """

  Ensure data-block previews are available and up-to-date (to be saved in .blend file, only for some types like materials, textures, etc.)

  """

  ...

def properties_add(data_path: str = '') -> None:

  """

  Add your own property to the data-block

  """

  ...

def properties_context_change(context: str = '') -> None:

  """

  Jump to a different tab inside the properties editor

  """

  ...

def properties_edit(data_path: str = '', property_name: str = '', property_type: str = 'FLOAT', is_overridable_library: bool = False, description: str = '', use_soft_limits: bool = False, array_length: int = 3, default_int: typing.Tuple[int, ...] = (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), min_int: int = -10000, max_int: int = 10000, soft_min_int: int = -10000, soft_max_int: int = 10000, step_int: int = 1, default_bool: typing.Tuple[bool, ...] = (False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False), default_float: typing.Tuple[float, ...] = (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0), min_float: float = -10000.0, max_float: float = -10000.0, soft_min_float: float = -10000.0, soft_max_float: float = -10000.0, precision: int = 3, step_float: float = 0.1, subtype: str = 'NONE', default_string: str = '', eval_string: str = '') -> None:

  """

  Change a custom property's type, or adjust how it is displayed in the interface

  """

  ...

def properties_edit_value(data_path: str = '', property_name: str = '', eval_string: str = '') -> None:

  """

  Edit the value of a custom property

  """

  ...

def properties_remove(data_path: str = '', property_name: str = '') -> None:

  """

  Internal use (edit a property data_path)

  """

  ...

def quit_blender() -> None:

  """

  Quit Blender

  """

  ...

def radial_control(data_path_primary: str = '', data_path_secondary: str = '', use_secondary: str = '', rotation_path: str = '', color_path: str = '', fill_color_path: str = '', fill_color_override_path: str = '', fill_color_override_test_path: str = '', zoom_path: str = '', image_id: str = '', secondary_tex: bool = False, release_confirm: bool = False) -> None:

  """

  Set some size property (e.g. brush size) with mouse wheel

  """

  ...

def read_factory_settings(use_factory_startup_app_template_only: bool = False, app_template: str = 'Template', use_empty: bool = False) -> None:

  """

  Load factory default startup file and preferences. To make changes permanent, use "Save Startup File" and "Save Preferences"

  """

  ...

def read_factory_userpref(use_factory_startup_app_template_only: bool = False) -> None:

  """

  Load factory default preferences. To make changes to preferences permanent, use "Save Preferences"

  """

  ...

def read_history() -> None:

  """

  Reloads history and bookmarks

  """

  ...

def read_homefile(filepath: str = '', load_ui: bool = True, use_splash: bool = False, use_factory_startup: bool = False, use_factory_startup_app_template_only: bool = False, app_template: str = 'Template', use_empty: bool = False) -> None:

  """

  Open the default file (doesn't save the current file)

  """

  ...

def read_userpref() -> None:

  """

  Load last saved preferences

  """

  ...

def recover_auto_save(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = False, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'LIST_VERTICAL', sort_method: str = '', use_scripts: bool = True) -> None:

  """

  Open an automatically saved file to recover it

  """

  ...

def recover_last_session(use_scripts: bool = True) -> None:

  """

  Open the last closed file ("quit.blend")

  """

  ...

def redraw_timer(type: str = 'DRAW', iterations: int = 10, time_limit: float = 0.0) -> None:

  """

  Simple redraw timer to test the speed of updating the interface

  """

  ...

def revert_mainfile(use_scripts: bool = True) -> None:

  """

  Reload the saved file

  """

  ...

def save_as_mainfile(filepath: str = '', hide_props_region: bool = True, check_existing: bool = True, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'DEFAULT', sort_method: str = '', compress: bool = False, relative_remap: bool = True, copy: bool = False) -> None:

  """

  Save the current file in the desired location

  """

  ...

def save_homefile() -> None:

  """

  Make the current file the default .blend file

  """

  ...

def save_mainfile(filepath: str = '', hide_props_region: bool = True, check_existing: bool = True, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'DEFAULT', sort_method: str = '', compress: bool = False, relative_remap: bool = False, exit: bool = False) -> None:

  """

  Save the current Blender file

  """

  ...

def save_userpref() -> None:

  """

  Make the current preferences default

  """

  ...

def search_menu() -> None:

  """

  Pop-up a search over all menus in the current context

  """

  ...

def search_operator() -> None:

  """

  Pop-up a search over all available operators in current context

  """

  ...

def set_stereo_3d(display_mode: str = 'ANAGLYPH', anaglyph_type: str = 'RED_CYAN', interlace_type: str = 'ROW_INTERLEAVED', use_interlace_swap: bool = False, use_sidebyside_crosseyed: bool = False) -> None:

  """

  Toggle 3D stereo support for current window (or change the display mode)

  """

  ...

def splash() -> None:

  """

  Open the splash screen with release info

  """

  ...

def splash_about() -> None:

  """

  Open a window with information about Blender

  """

  ...

def stl_import(filepath: str = '', directory: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'DEFAULT', sort_method: str = '', global_scale: float = 1.0, use_scene_unit: bool = False, use_facet_normal: bool = False, forward_axis: str = 'Y', up_axis: str = 'Z', use_mesh_validate: bool = False, filter_glob: str = '*args.stl') -> None:

  """

  Import an STL file as an object

  """

  ...

def sysinfo(filepath: str = '') -> None:

  """

  Generate system information, saved into a text file

  """

  ...

def tool_set_by_id(name: str = '', cycle: bool = False, as_fallback: bool = False, space_type: str = 'EMPTY') -> None:

  """

  Set the tool by name (for keymaps)

  """

  ...

def tool_set_by_index(index: int = 0, cycle: bool = False, expand: bool = True, as_fallback: bool = False, space_type: str = 'EMPTY') -> None:

  """

  Set the tool by index (for keymaps)

  """

  ...

def toolbar() -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

  ...

def toolbar_fallback_pie() -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

  ...

def toolbar_prompt() -> None:

  """

  Leader key like functionality for accessing tools

  """

  ...

def url_open(url: str = '') -> None:

  """

  Open a website in the web browser

  """

  ...

def url_open_preset(type: str = '', id: str = '') -> None:

  """

  Open a preset website in the web browser

  """

  ...

def window_close() -> None:

  """

  Close the current window

  """

  ...

def window_fullscreen_toggle() -> None:

  """

  Toggle the current window full-screen

  """

  ...

def window_new() -> None:

  """

  Create a new window

  """

  ...

def window_new_main() -> None:

  """

  Create a new main window with its own workspace and scene selection

  """

  ...



"""


Object Axis Items
^^^^^^^^^^^^^^^^^

:POS_X:           
  +X.

:POS_Y:           
  +Y.

:POS_Z:           
  +Z.

:NEG_X:           
  -X.

:NEG_Y:           
  -Y.

:NEG_Z:           
  -Z.

.. _rna-enum-object-axis-items:

"""

import typing



"""


Bake Pass Type Items
^^^^^^^^^^^^^^^^^^^^

:COMBINED:        
  Combined.

:AO:              
  Ambient Occlusion.

:SHADOW:          
  Shadow.

:POSITION:        
  Position.

:NORMAL:          
  Normal.

:UV:              
  UV.

:ROUGHNESS:       
  ROUGHNESS.

:EMIT:            
  Emit.

:ENVIRONMENT:     
  Environment.

:DIFFUSE:         
  Diffuse.

:GLOSSY:          
  Glossy.

:TRANSMISSION:    
  Transmission.

.. _rna-enum-bake-pass-type-items:

"""

import typing



"""


Node Operators
**************

:func:`add_collection`

:func:`add_file`

:func:`add_group`

:func:`add_group_asset`

:func:`add_mask`

:func:`add_node`

:func:`add_object`

:func:`add_reroute`

:func:`add_search`

:func:`attach`

:func:`backimage_fit`

:func:`backimage_move`

:func:`backimage_sample`

:func:`backimage_zoom`

:func:`clear_viewer_border`

:func:`clipboard_copy`

:func:`clipboard_paste`

:func:`collapse_hide_unused_toggle`

:func:`cryptomatte_layer_add`

:func:`cryptomatte_layer_remove`

:func:`deactivate_viewer`

:func:`delete`

:func:`delete_reconnect`

:func:`detach`

:func:`detach_translate_attach`

:func:`duplicate`

:func:`duplicate_move`

:func:`duplicate_move_keep_inputs`

:func:`duplicate_move_linked`

:func:`find_node`

:func:`gltf_settings_node_operator`

:func:`group_edit`

:func:`group_insert`

:func:`group_make`

:func:`group_separate`

:func:`group_ungroup`

:func:`hide_socket_toggle`

:func:`hide_toggle`

:func:`insert_offset`

:func:`join`

:func:`link`

:func:`link_make`

:func:`link_viewer`

:func:`links_cut`

:func:`links_detach`

:func:`links_mute`

:func:`move_detach_links`

:func:`move_detach_links_release`

:func:`mute_toggle`

:func:`new_geometry_node_group_assign`

:func:`new_geometry_nodes_modifier`

:func:`new_node_tree`

:func:`node_color_preset_add`

:func:`node_copy_color`

:func:`options_toggle`

:func:`output_file_add_socket`

:func:`output_file_move_active_socket`

:func:`output_file_remove_active_socket`

:func:`parent_set`

:func:`preview_toggle`

:func:`read_viewlayers`

:func:`render_changed`

:func:`resize`

:func:`select`

:func:`select_all`

:func:`select_box`

:func:`select_circle`

:func:`select_grouped`

:func:`select_lasso`

:func:`select_link_viewer`

:func:`select_linked_from`

:func:`select_linked_to`

:func:`select_same_type_step`

:func:`shader_script_update`

:func:`switch_view_update`

:func:`translate_attach`

:func:`translate_attach_remove_on_cancel`

:func:`tree_path_parent`

:func:`tree_socket_add`

:func:`tree_socket_change_type`

:func:`tree_socket_move`

:func:`tree_socket_remove`

:func:`view_all`

:func:`view_selected`

:func:`viewer_border`

"""

import typing

def add_collection(name: str = '', session_uuid: int = 0) -> None:

  """

  Add a collection info node to the current node editor

  """

  ...

def add_file(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = True, filter_movie: bool = True, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '', name: str = '', session_uuid: int = 0) -> None:

  """

  Add a file node to the current node editor

  """

  ...

def add_group(name: str = '', session_uuid: int = 0) -> None:

  """

  Add an existing node group to the current node editor

  """

  ...

def add_group_asset() -> None:

  """

  Add a node group asset to the active node tree

  """

  ...

def add_mask(name: str = '', session_uuid: int = 0) -> None:

  """

  Add a mask node to the current node editor

  """

  ...

def add_node(type: str = '', use_transform: bool = False, settings: typing.Union[typing.Sequence[NodeSetting], typing.Mapping[str, NodeSetting], bpy.types.bpy_prop_collection] = None) -> None:

  """

  Add a node to the active tree

  """

  ...

def add_object(name: str = '', session_uuid: int = 0) -> None:

  """

  Add an object info node to the current node editor

  """

  ...

def add_reroute(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, cursor: int = 8) -> None:

  """

  Add a reroute node

  """

  ...

def add_search(use_transform: bool = True) -> None:

  """

  Search for nodes and add one to the active tree

  """

  ...

def attach() -> None:

  """

  Attach active node to a frame

  """

  ...

def backimage_fit() -> None:

  """

  Fit the background image to the view

  """

  ...

def backimage_move() -> None:

  """

  Move node backdrop

  """

  ...

def backimage_sample() -> None:

  """

  Use mouse to sample background image

  """

  ...

def backimage_zoom(factor: float = 1.2) -> None:

  """

  Zoom in/out the background image

  """

  ...

def clear_viewer_border() -> None:

  """

  Clear the boundaries for viewer operations

  """

  ...

def clipboard_copy() -> None:

  """

  Copies selected nodes to the clipboard

  """

  ...

def clipboard_paste(offset: typing.Tuple[float, float] = (0.0, 0.0)) -> None:

  """

  Pastes nodes from the clipboard to the active node tree

  """

  ...

def collapse_hide_unused_toggle() -> None:

  """

  Toggle collapsed nodes and hide unused sockets

  """

  ...

def cryptomatte_layer_add() -> None:

  """

  Add a new input layer to a Cryptomatte node

  """

  ...

def cryptomatte_layer_remove() -> None:

  """

  Remove layer from a Cryptomatte node

  """

  ...

def deactivate_viewer() -> None:

  """

  Deactivate selected viewer node in geometry nodes

  """

  ...

def delete() -> None:

  """

  Remove selected nodes

  """

  ...

def delete_reconnect() -> None:

  """

  Remove nodes and reconnect nodes as if deletion was muted

  """

  ...

def detach() -> None:

  """

  Detach selected nodes from parents

  """

  ...

def detach_translate_attach(NODE_OT_detach: NODE_OT_detach = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None, NODE_OT_attach: NODE_OT_attach = None) -> None:

  """

  Detach nodes, move and attach to frame

  """

  ...

def duplicate(keep_inputs: bool = False, linked: bool = True) -> None:

  """

  Duplicate selected nodes

  """

  ...

def duplicate_move(NODE_OT_duplicate: NODE_OT_duplicate = None, NODE_OT_translate_attach: NODE_OT_translate_attach = None) -> None:

  """

  Duplicate selected nodes and move them

  """

  ...

def duplicate_move_keep_inputs(NODE_OT_duplicate: NODE_OT_duplicate = None, NODE_OT_translate_attach: NODE_OT_translate_attach = None) -> None:

  """

  Duplicate selected nodes keeping input links and move them

  """

  ...

def duplicate_move_linked(NODE_OT_duplicate: NODE_OT_duplicate = None, NODE_OT_translate_attach: NODE_OT_translate_attach = None) -> None:

  """

  Duplicate selected nodes, but not their node trees, and move them

  """

  ...

def find_node() -> None:

  """

  Search for a node by name and focus and select it

  """

  ...

def gltf_settings_node_operator() -> None:

  """

  Add a node to the active tree for glTF export

  """

  ...

def group_edit(exit: bool = False) -> None:

  """

  Edit node group

  """

  ...

def group_insert() -> None:

  """

  Insert selected nodes into a node group

  """

  ...

def group_make() -> None:

  """

  Make group from selected nodes

  """

  ...

def group_separate(type: str = 'COPY') -> None:

  """

  Separate selected nodes from the node group

  """

  ...

def group_ungroup() -> None:

  """

  Ungroup selected nodes

  """

  ...

def hide_socket_toggle() -> None:

  """

  Toggle unused node socket display

  """

  ...

def hide_toggle() -> None:

  """

  Toggle hiding of selected nodes

  """

  ...

def insert_offset() -> None:

  """

  Automatically offset nodes on insertion

  """

  ...

def join() -> None:

  """

  Attach selected nodes to a new common frame

  """

  ...

def link(detach: bool = False, drag_start: typing.Tuple[float, float] = (0.0, 0.0), inside_padding: float = 2.0, outside_padding: float = 0.0, speed_ramp: float = 1.0, max_speed: float = 26.0, delay: float = 0.5, zoom_influence: float = 0.5) -> None:

  """

  Use the mouse to create a link between two nodes

  """

  ...

def link_make(replace: bool = False) -> None:

  """

  Makes a link between selected output in input sockets

  """

  ...

def link_viewer() -> None:

  """

  Link to viewer node

  """

  ...

def links_cut(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, cursor: int = 12) -> None:

  """

  Use the mouse to cut (remove) some links

  """

  ...

def links_detach() -> None:

  """

  Remove all links to selected nodes, and try to connect neighbor nodes together

  """

  ...

def links_mute(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, cursor: int = 35) -> None:

  """

  Use the mouse to mute links

  """

  ...

def move_detach_links(NODE_OT_links_detach: NODE_OT_links_detach = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None, NODE_OT_insert_offset: NODE_OT_insert_offset = None) -> None:

  """

  Move a node to detach links

  """

  ...

def move_detach_links_release(NODE_OT_links_detach: NODE_OT_links_detach = None, NODE_OT_translate_attach: NODE_OT_translate_attach = None) -> None:

  """

  Move a node to detach links

  """

  ...

def mute_toggle() -> None:

  """

  Toggle muting of selected nodes

  """

  ...

def new_geometry_node_group_assign() -> None:

  """

  Create a new geometry node group and assign it to the active modifier

  """

  ...

def new_geometry_nodes_modifier() -> None:

  """

  Create a new modifier with a new geometry node group

  """

  ...

def new_node_tree(type: str = '', name: str = 'NodeTree') -> None:

  """

  Create a new node tree

  """

  ...

def node_color_preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Node Color Preset

  """

  ...

def node_copy_color() -> None:

  """

  Copy color to all selected nodes

  """

  ...

def options_toggle() -> None:

  """

  Toggle option buttons display for selected nodes

  """

  ...

def output_file_add_socket(file_path: str = 'Image') -> None:

  """

  Add a new input to a file output node

  """

  ...

def output_file_move_active_socket(direction: str = 'DOWN') -> None:

  """

  Move the active input of a file output node up or down the list

  """

  ...

def output_file_remove_active_socket() -> None:

  """

  Remove the active input from a file output node

  """

  ...

def parent_set() -> None:

  """

  Attach selected nodes

  """

  ...

def preview_toggle() -> None:

  """

  Toggle preview display for selected nodes

  """

  ...

def read_viewlayers() -> None:

  """

  Read all render layers of all used scenes

  """

  ...

def render_changed() -> None:

  """

  Render current scene, when input node's layer has been changed

  """

  ...

def resize() -> None:

  """

  Resize a node

  """

  ...

def select(extend: bool = False, deselect: bool = False, toggle: bool = False, deselect_all: bool = False, select_passthrough: bool = False, location: typing.Tuple[int, int] = (0, 0), socket_select: bool = False, clear_viewer: bool = False) -> None:

  """

  Select the node under the cursor

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  (De)select all nodes

  """

  ...

def select_box(tweak: bool = False, xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Use box selection to select nodes

  """

  ...

def select_circle(x: int = 0, y: int = 0, radius: int = 25, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Use circle selection to select nodes

  """

  ...

def select_grouped(extend: bool = False, type: str = 'TYPE') -> None:

  """

  Select nodes with similar properties

  """

  ...

def select_lasso(tweak: bool = False, path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, mode: str = 'SET') -> None:

  """

  Select nodes using lasso selection

  """

  ...

def select_link_viewer(NODE_OT_select: NODE_OT_select = None, NODE_OT_link_viewer: NODE_OT_link_viewer = None) -> None:

  """

  Select node and link it to a viewer node

  """

  ...

def select_linked_from() -> None:

  """

  Select nodes linked from the selected ones

  """

  ...

def select_linked_to() -> None:

  """

  Select nodes linked to the selected ones

  """

  ...

def select_same_type_step(prev: bool = False) -> None:

  """

  Activate and view same node type, step by step

  """

  ...

def shader_script_update() -> None:

  """

  Update shader script node with new sockets and options from the script

  """

  ...

def switch_view_update() -> None:

  """

  Update views of selected node

  """

  ...

def translate_attach(TRANSFORM_OT_translate: TRANSFORM_OT_translate = None, NODE_OT_attach: NODE_OT_attach = None, NODE_OT_insert_offset: NODE_OT_insert_offset = None) -> None:

  """

  Move nodes and attach to frame

  """

  ...

def translate_attach_remove_on_cancel(TRANSFORM_OT_translate: TRANSFORM_OT_translate = None, NODE_OT_attach: NODE_OT_attach = None, NODE_OT_insert_offset: NODE_OT_insert_offset = None) -> None:

  """

  Move nodes and attach to frame

  """

  ...

def tree_path_parent() -> None:

  """

  Go to parent node tree

  """

  ...

def tree_socket_add(in_out: str = 'IN') -> None:

  """

  Add an input or output to the active node tree

  """

  ...

def tree_socket_change_type(in_out: str = 'IN', socket_type: str = 'DEFAULT') -> None:

  """

  Change the type of an input or output of the active node tree

  """

  ...

def tree_socket_move(direction: str = 'UP', in_out: str = 'IN') -> None:

  """

  Move a socket up or down in the active node tree's interface

  """

  ...

def tree_socket_remove(in_out: str = 'IN') -> None:

  """

  Remove an input or output from the active node tree

  """

  ...

def view_all() -> None:

  """

  Resize view so you can see all nodes

  """

  ...

def view_selected() -> None:

  """

  Resize view so you can see selected nodes

  """

  ...

def viewer_border(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True) -> None:

  """

  Set the boundaries for viewer operations

  """

  ...



"""


Boid Operators
**************

:func:`rule_add`

:func:`rule_del`

:func:`rule_move_down`

:func:`rule_move_up`

:func:`state_add`

:func:`state_del`

:func:`state_move_down`

:func:`state_move_up`

"""

import typing

def rule_add(type: str = 'GOAL') -> None:

  """

  Add a boid rule to the current boid state

  """

  ...

def rule_del() -> None:

  """

  Delete current boid rule

  """

  ...

def rule_move_down() -> None:

  """

  Move boid rule down in the list

  """

  ...

def rule_move_up() -> None:

  """

  Move boid rule up in the list

  """

  ...

def state_add() -> None:

  """

  Add a boid state to the particle system

  """

  ...

def state_del() -> None:

  """

  Delete current boid state

  """

  ...

def state_move_down() -> None:

  """

  Move boid state down in the list

  """

  ...

def state_move_up() -> None:

  """

  Move boid state up in the list

  """

  ...



"""


Sculpt Operators
****************

:func:`brush_stroke`

:func:`cloth_filter`

:func:`color_filter`

:func:`detail_flood_fill`

:func:`dynamic_topology_toggle`

:func:`dyntopo_detail_size_edit`

:func:`expand`

:func:`face_set_box_gesture`

:func:`face_set_change_visibility`

:func:`face_set_edit`

:func:`face_set_lasso_gesture`

:func:`face_sets_create`

:func:`face_sets_init`

:func:`face_sets_randomize_colors`

:func:`mask_by_color`

:func:`mask_expand`

:func:`mask_filter`

:func:`mask_from_cavity`

:func:`mask_init`

:func:`mesh_filter`

:func:`optimize`

:func:`project_line_gesture`

:func:`reveal_all`

:func:`sample_color`

:func:`sample_detail_size`

:func:`sculptmode_toggle`

:func:`set_detail_size`

:func:`set_persistent_base`

:func:`set_pivot_position`

:func:`symmetrize`

:func:`trim_box_gesture`

:func:`trim_lasso_gesture`

:func:`uv_sculpt_stroke`

"""

import typing

import mathutils

def brush_stroke(stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, mode: str = 'NORMAL', ignore_background_click: bool = False) -> None:

  """

  Sculpt a stroke into the geometry

  """

  ...

def cloth_filter(area_normal_radius: float = 0.25, strength: float = 1.0, type: str = 'GRAVITY', force_axis: typing.Set[str] = {'X', 'Y', 'Z'}, orientation: str = 'LOCAL', cloth_mass: float = 1.0, cloth_damping: float = 0.0, use_face_sets: bool = False, use_collisions: bool = False) -> None:

  """

  Applies a cloth simulation deformation to the entire mesh

  """

  ...

def color_filter(area_normal_radius: float = 0.25, strength: float = 1.0, type: str = 'HUE', fill_color: mathutils.Color = (0.0, 0.0, 0.0)) -> None:

  """

  Applies a filter to modify the active color attribute

  """

  ...

def detail_flood_fill() -> None:

  """

  Flood fill the mesh with the selected detail setting

  """

  ...

def dynamic_topology_toggle() -> None:

  """

  Dynamic topology alters the mesh topology while sculpting

  """

  ...

def dyntopo_detail_size_edit() -> None:

  """

  Modify the detail size of dyntopo interactively

  """

  ...

def expand(target: str = 'MASK', falloff_type: str = 'GEODESIC', invert: bool = False, use_mask_preserve: bool = False, use_falloff_gradient: bool = False, use_modify_active: bool = False, use_reposition_pivot: bool = True, max_geodesic_move_preview: int = 10000, use_auto_mask: bool = False) -> None:

  """

  Generic sculpt expand operator

  """

  ...

def face_set_box_gesture(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, use_front_faces_only: bool = False, use_limit_to_segment: bool = False) -> None:

  """

  Add face set within the box as you move the brush

  """

  ...

def face_set_change_visibility(mode: str = 'TOGGLE') -> None:

  """

  Change the visibility of the Face Sets of the sculpt

  """

  ...

def face_set_edit(mode: str = 'GROW', modify_hidden: bool = True) -> None:

  """

  Edits the current active Face Set

  """

  ...

def face_set_lasso_gesture(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, use_front_faces_only: bool = False, use_limit_to_segment: bool = False) -> None:

  """

  Add face set within the lasso as you move the brush

  """

  ...

def face_sets_create(mode: str = 'MASKED') -> None:

  """

  Create a new Face Set

  """

  ...

def face_sets_init(mode: str = 'LOOSE_PARTS', threshold: float = 0.5) -> None:

  """

  Initializes all Face Sets in the mesh

  """

  ...

def face_sets_randomize_colors() -> None:

  """

  Generates a new set of random colors to render the Face Sets in the viewport

  """

  ...

def mask_by_color(contiguous: bool = False, invert: bool = False, preserve_previous_mask: bool = False, threshold: float = 0.35) -> None:

  """

  Creates a mask based on the active color attribute

  """

  ...

def mask_expand(invert: bool = True, use_cursor: bool = True, update_pivot: bool = True, smooth_iterations: int = 2, mask_speed: int = 5, use_normals: bool = True, keep_previous_mask: bool = False, edge_sensitivity: int = 300, create_face_set: bool = False) -> None:

  """

  Expands a mask from the initial active vertex under the cursor

  """

  ...

def mask_filter(filter_type: str = 'SMOOTH', iterations: int = 1, auto_iteration_count: bool = True) -> None:

  """

  Applies a filter to modify the current mask

  """

  ...

def mask_from_cavity(mix_mode: str = 'MIX', mix_factor: float = 1.0, settings_source: str = 'OPERATOR', factor: float = 0.5, blur_steps: int = 2, use_curve: bool = False, invert: bool = False) -> None:

  """

  Creates a mask based on the curvature of the surface

  """

  ...

def mask_init(mode: str = 'RANDOM_PER_VERTEX') -> None:

  """

  Creates a new mask for the entire mesh

  """

  ...

def mesh_filter(area_normal_radius: float = 0.25, strength: float = 1.0, type: str = 'INFLATE', deform_axis: typing.Set[str] = {'X', 'Y', 'Z'}, orientation: str = 'LOCAL', surface_smooth_shape_preservation: float = 0.5, surface_smooth_current_vertex: float = 0.5, sharpen_smooth_ratio: float = 0.35, sharpen_intensify_detail_strength: float = 0.0, sharpen_curvature_smooth_iterations: int = 0) -> None:

  """

  Applies a filter to modify the current mesh

  """

  ...

def optimize() -> None:

  """

  Recalculate the sculpt BVH to improve performance

  """

  ...

def project_line_gesture(xstart: int = 0, xend: int = 0, ystart: int = 0, yend: int = 0, flip: bool = False, cursor: int = 5, use_front_faces_only: bool = False, use_limit_to_segment: bool = False) -> None:

  """

  Project the geometry onto a plane defined by a line

  """

  ...

def reveal_all() -> None:

  """

  Unhide all geometry

  """

  ...

def sample_color() -> None:

  """

  Sample the vertex color of the active vertex

  """

  ...

def sample_detail_size(location: typing.Tuple[int, int] = (0, 0), mode: str = 'DYNTOPO') -> None:

  """

  Sample the mesh detail on clicked point

  """

  ...

def sculptmode_toggle() -> None:

  """

  Toggle sculpt mode in 3D view

  """

  ...

def set_detail_size() -> None:

  """

  Set the mesh detail (either relative or constant one, depending on current dyntopo mode)

  """

  ...

def set_persistent_base() -> None:

  """

  Reset the copy of the mesh that is being sculpted on

  """

  ...

def set_pivot_position(mode: str = 'UNMASKED', mouse_x: float = 0.0, mouse_y: float = 0.0) -> None:

  """

  Sets the sculpt transform pivot position

  """

  ...

def symmetrize(merge_tolerance: float = 0.0005) -> None:

  """

  Symmetrize the topology modifications

  """

  ...

def trim_box_gesture(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, use_front_faces_only: bool = False, use_limit_to_segment: bool = False, trim_mode: str = 'DIFFERENCE', use_cursor_depth: bool = False, trim_orientation: str = 'VIEW', trim_extrude_mode: str = 'FIXED') -> None:

  """

  Trims the mesh within the box as you move the brush

  """

  ...

def trim_lasso_gesture(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, use_front_faces_only: bool = False, use_limit_to_segment: bool = False, trim_mode: str = 'DIFFERENCE', use_cursor_depth: bool = False, trim_orientation: str = 'VIEW', trim_extrude_mode: str = 'FIXED') -> None:

  """

  Trims the mesh within the lasso as you move the brush

  """

  ...

def uv_sculpt_stroke(mode: str = 'NORMAL') -> None:

  """

  Sculpt UVs using a brush

  """

  ...



"""


Operator Type Flag Items
^^^^^^^^^^^^^^^^^^^^^^^^

:REGISTER:        
  Register.

  Display in the info window and support the redo toolbar panel.

:UNDO:            
  Undo.

  Push an undo event (needed for operator redo).

:UNDO_GROUPED:    
  Grouped Undo.

  Push a single undo event for repeated instances of this operator.

:BLOCKING:        
  Blocking.

  Block anything else from using the cursor.

:MACRO:           
  Macro.

  Use to check if an operator is a macro.

:GRAB_CURSOR:     
  Grab Pointer.

  Use so the operator grabs the mouse focus, enables wrapping when continuous grab is enabled.

:GRAB_CURSOR_X:   
  Grab Pointer X.

  Grab, only warping the X axis.

:GRAB_CURSOR_Y:   
  Grab Pointer Y.

  Grab, only warping the Y axis.

:DEPENDS_ON_CURSOR:
  Depends on Cursor.

  The initial cursor location is used, when running from a menus or buttons the user is prompted to place the cursor before beginning the operation.

:PRESET:          
  Preset.

  Display a preset button with the operators settings.

:INTERNAL:        
  Internal.

  Removes the operator from search results.

.. _rna-enum-operator-type-flag-items:

"""

import typing



"""


Transform Orientation Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:GLOBAL:          
  Global.

  Align the transformation axes to world space.

:LOCAL:           
  Local.

  Align the transformation axes to the selected objects' local space.

:NORMAL:          
  Normal.

  Align the transformation axes to average normal of selected elements (bone Y axis for pose mode).

:GIMBAL:          
  Gimbal.

  Align each axis to the Euler rotation axis as used for input.

:VIEW:            
  View.

  Align the transformation axes to the window.

:CURSOR:          
  Cursor.

  Align the transformation axes to the 3D cursor.

.. _rna-enum-transform-orientation-items:

"""

import typing



"""


Dpaint Operators
****************

:func:`bake`

:func:`output_toggle`

:func:`surface_slot_add`

:func:`surface_slot_remove`

:func:`type_toggle`

"""

import typing

def bake() -> None:

  """

  Bake dynamic paint image sequence surface

  """

  ...

def output_toggle(output: str = 'A') -> None:

  """

  Add or remove Dynamic Paint output data layer

  """

  ...

def surface_slot_add() -> None:

  """

  Add a new Dynamic Paint surface slot

  """

  ...

def surface_slot_remove() -> None:

  """

  Remove the selected surface slot

  """

  ...

def type_toggle(type: str = 'CANVAS') -> None:

  """

  Toggle whether given type is active or not

  """

  ...



"""


Image Type Items
^^^^^^^^^^^^^^^^

.. _rna-enum-image-type-items:

**Image**

:BMP:             
  BMP.

  Output image in bitmap format.

:IRIS:            
  Iris.

  Output image in SGI IRIS format.

:PNG:             
  PNG.

  Output image in PNG format.

:JPEG:            
  JPEG.

  Output image in JPEG format.

:JPEG2000:        
  JPEG 2000.

  Output image in JPEG 2000 format.

:TARGA:           
  Targa.

  Output image in Targa format.

:TARGA_RAW:       
  Targa Raw.

  Output image in uncompressed Targa format.

======================================================================

:CINEON:          
  Cineon.

  Output image in Cineon format.

:DPX:             
  DPX.

  Output image in DPX format.

:OPEN_EXR_MULTILAYER:
  OpenEXR MultiLayer.

  Output image in multilayer OpenEXR format.

:OPEN_EXR:        
  OpenEXR.

  Output image in OpenEXR format.

:HDR:             
  Radiance HDR.

  Output image in Radiance HDR format.

:TIFF:            
  TIFF.

  Output image in TIFF format.

**Movie**

:AVI_JPEG:        
  AVI JPEG.

  Output video in AVI JPEG format.

:AVI_RAW:         
  AVI Raw.

  Output video in AVI Raw format.

:FFMPEG:          
  FFmpeg Video.

  The most versatile way to output video files.

"""

import typing



"""


Dt Method Loop Items
^^^^^^^^^^^^^^^^^^^^

:TOPOLOGY:        
  Topology.

  Copy from identical topology meshes.

:NEAREST_NORMAL:  
  Nearest Corner and Best Matching Normal.

  Copy from nearest corner which has the best matching normal.

:NEAREST_POLYNOR: 
  Nearest Corner and Best Matching Face Normal.

  Copy from nearest corner which has the face with the best matching normal to destination corner's face one.

:NEAREST_POLY:    
  Nearest Corner of Nearest Face.

  Copy from nearest corner of nearest polygon.

:POLYINTERP_NEAREST:
  Nearest Face Interpolated.

  Copy from interpolated corners of the nearest source polygon.

:POLYINTERP_LNORPROJ:
  Projected Face Interpolated.

  Copy from interpolated corners of the source polygon hit by corner normal projection.

.. _rna-enum-dt-method-loop-items:

"""

import typing



"""


Curves Operators
****************

:func:`convert_from_particle_system`

:func:`convert_to_particle_system`

:func:`sculptmode_toggle`

:func:`select_all`

:func:`select_end`

:func:`select_random`

:func:`set_selection_domain`

:func:`snap_curves_to_surface`

:func:`surface_set`

"""

import typing

def convert_from_particle_system() -> None:

  """

  Add a new curves object based on the current state of the particle system

  """

  ...

def convert_to_particle_system() -> None:

  """

  Add a new or update an existing hair particle system on the surface object

  """

  ...

def sculptmode_toggle() -> None:

  """

  Enter/Exit sculpt mode for curves

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  (De)select all control points

  """

  ...

def select_end(end_points: bool = True, amount: int = 1) -> None:

  """

  Select end points of curves

  """

  ...

def select_random(seed: int = 0, probability: float = 0.5) -> None:

  """

  Randomizes existing selection or create new random selection

  """

  ...

def set_selection_domain(domain: str = 'POINT') -> None:

  """

  Change the mode used for selection masking in curves sculpt mode

  """

  ...

def snap_curves_to_surface(attach_mode: str = 'NEAREST') -> None:

  """

  Move curves so that the first point is exactly on the surface mesh

  """

  ...

def surface_set() -> None:

  """

  Use the active object as surface for selected curves objects and set it as the parent

  """

  ...



"""


Brush Image Tool Items
^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

:SOFTEN:          
  Soften.

:SMEAR:           
  Smear.

:CLONE:           
  Clone.

:FILL:            
  Fill.

:MASK:            
  Mask.

.. _rna-enum-brush-image-tool-items:

"""

import typing



"""


Object Mode Items
^^^^^^^^^^^^^^^^^

:OBJECT:          
  Object Mode.

:EDIT:            
  Edit Mode.

:POSE:            
  Pose Mode.

:SCULPT:          
  Sculpt Mode.

:VERTEX_PAINT:    
  Vertex Paint.

:WEIGHT_PAINT:    
  Weight Paint.

:TEXTURE_PAINT:   
  Texture Paint.

:PARTICLE_EDIT:   
  Particle Edit.

:EDIT_GPENCIL:    
  Edit Mode.

  Edit Grease Pencil Strokes.

:SCULPT_GPENCIL:  
  Sculpt Mode.

  Sculpt Grease Pencil Strokes.

:PAINT_GPENCIL:   
  Draw Mode.

  Paint Grease Pencil Strokes.

:WEIGHT_GPENCIL:  
  Weight Paint.

  Grease Pencil Weight Paint Strokes.

:VERTEX_GPENCIL:  
  Vertex Paint.

  Grease Pencil Vertex Paint Strokes.

:SCULPT_CURVES:   
  Sculpt Mode.

.. _rna-enum-object-mode-items:

"""

import typing



"""


KDTree Utilities (mathutils.kdtree)
***********************************

Generic 3-dimensional kd-tree to perform spatial searches.

.. code::

  import mathutils

  # create a kd-tree from a mesh
  from bpy import context
  obj = context.object

  mesh = obj.data
  size = len(mesh.vertices)
  kd = mathutils.kdtree.KDTree(size)

  for i, v in enumerate(mesh.vertices):
      kd.insert(v.co, i)

  kd.balance()


  # Find the closest point to the center
  co_find = (0.0, 0.0, 0.0)
  co, index, dist = kd.find(co_find)
  print("Close to center:", co, index, dist)

  # 3d cursor relative to the object data
  co_find = obj.matrix_world.inverted() @ context.scene.cursor.location

  # Find the closest 10 points to the 3d cursor
  print("Close 10 points")
  for (co, index, dist) in kd.find_n(co_find, 10):
      print("    ", co, index, dist)


  # Find points within a radius of the 3d cursor
  print("Close points within 0.5 distance")
  for (co, index, dist) in kd.find_range(co_find, 0.5):
      print("    ", co, index, dist)

:class:`KDTree`

"""

import typing

class KDTree:

  """

  KdTree(size) -> new kd-tree initialized to hold ``size`` items.

  Note: :class:`KDTree.balance` must have been called before using any of the ``find`` methods.

  Note: This builds the entire tree, avoid calling after each insertion.

  """

  def balance(self) -> None:

    """

    Balance the tree.

    """

    ...

  def find(self, co: float, filter: typing.Callable = None) -> tuple:

    """

    Find nearest point to ``co``.

    """

    ...

  def find_n(self, co: float, n: int) -> list:

    """

    Find nearest ``n`` points to ``co``.

    """

    ...

  def find_range(self, co: float, radius: float) -> list:

    """

    Find all points within ``radius`` of ``co``.

    """

    ...

  def insert(self, co: float, index: int) -> None:

    """

    Insert a point into the KDTree.

    """

    ...



"""


Id Type Items
^^^^^^^^^^^^^

:ACTION:          
  Action.

:ARMATURE:        
  Armature.

:BRUSH:           
  Brush.

:CACHEFILE:       
  Cache File.

:CAMERA:          
  Camera.

:COLLECTION:      
  Collection.

:CURVE:           
  Curve.

:CURVES:          
  Curves.

:FONT:            
  Font.

:GREASEPENCIL:    
  Grease Pencil.

:IMAGE:           
  Image.

:KEY:             
  Key.

:LATTICE:         
  Lattice.

:LIBRARY:         
  Library.

:LIGHT:           
  Light.

:LIGHT_PROBE:     
  Light Probe.

:LINESTYLE:       
  Line Style.

:MASK:            
  Mask.

:MATERIAL:        
  Material.

:MESH:            
  Mesh.

:META:            
  Metaball.

:MOVIECLIP:       
  Movie Clip.

:NODETREE:        
  Node Tree.

:OBJECT:          
  Object.

:PAINTCURVE:      
  Paint Curve.

:PALETTE:         
  Palette.

:PARTICLE:        
  Particle.

:POINTCLOUD:      
  Point Cloud.

:SCENE:           
  Scene.

:SIMULATION:      
  Simulation.

:SOUND:           
  Sound.

:SPEAKER:         
  Speaker.

:TEXT:            
  Text.

:TEXTURE:         
  Texture.

:VOLUME:          
  Volume.

:WINDOWMANAGER:   
  Window Manager.

:WORKSPACE:       
  Workspace.

:WORLD:           
  World.

.. _rna-enum-id-type-items:

"""

import typing



"""


GPU Types (gpu.types)
*********************

:class:`Buffer`

:class:`GPUBatch`

:class:`GPUFrameBuffer`

:class:`GPUIndexBuf`

:class:`GPUOffScreen`

:class:`GPUShader`

:class:`GPUShaderCreateInfo`

:class:`GPUStageInterfaceInfo`

:class:`GPUTexture`

:class:`GPUUniformBuf`

:class:`GPUVertBuf`

:class:`GPUVertFormat`

"""

import typing

import mathutils

import bpy

class Buffer:

  """

  For Python access to GPU functions requiring a pointer.

  return the buffer as a list

  """

  def __init__(self, format: str, dimensions: int, data: typing.Sequence[typing.Any]) -> None:

    """

    :arg format:      
      Format type to interpret the buffer.
Possible values are *FLOAT*, *INT*, *UINT*, *UBYTE*, *UINT_24_8* and *10_11_11_REV*.

    :type format:     
      str

    :arg dimensions:  
      Array describing the dimensions.

    :type dimensions: 
      int

    :arg data:        
      Optional data array.

    :type data:       
      sequence

    """

    ...

  dimensions: typing.Any = ...

  """

  Undocumented, consider `contributing <https://developer.blender.org/T51061>`_.

  """

class GPUBatch:

  """

  Reusable container for drawable geometry.

  """

  def __init__(self, type: str, buf: GPUVertBuf, elem: GPUIndexBuf = None) -> None:

    """

    :arg type:        
      The primitive type of geometry to be drawn.
Possible values are *POINTS*, *LINES*, *TRIS*, *LINE_STRIP*, *LINE_LOOP*, *TRI_STRIP*, *TRI_FAN*, *LINES_ADJ*, *TRIS_ADJ* and *LINE_STRIP_ADJ*.

    :type type:       
      str

    :arg buf:         
      Vertex buffer containing all or some of the attributes required for drawing.

    :type buf:        
      :class:`gpu.types.GPUVertBuf`

    :arg elem:        
      An optional index buffer.

    :type elem:       
      :class:`gpu.types.GPUIndexBuf`

    """

    ...

  def draw(self, program: GPUShader = None) -> None:

    """

    Run the drawing program with the parameters assigned to the batch.

    """

    ...

  def program_set(self, program: GPUShader) -> None:

    """

    Assign a shader to this batch that will be used for drawing when not overwritten later.
Note: This method has to be called in the draw context that the batch will be drawn in.
This function does not need to be called when you always
set the shader when calling :meth:`gpu.types.GPUBatch.draw`.

    """

    ...

  def vertbuf_add(self, buf: GPUVertBuf) -> None:

    """

    Add another vertex buffer to the Batch.
It is not possible to add more vertices to the batch using this method.
Instead it can be used to add more attributes to the existing vertices.
A good use case would be when you have a separate
vertex buffer for vertex positions and vertex normals.
Current a batch can have at most 16 vertex buffers.

    """

    ...

class GPUFrameBuffer:

  """

  This object gives access to framebuffer functionalities.
When a 'layer' is specified in a argument, a single layer of a 3D or array texture is attached to the frame-buffer.
For cube map textures, layer is translated into a cube map face.

  """

  def __init__(self, depth_slot: GPUTexture = None, color_slots: typing.Tuple[typing.Any, ...] = None) -> None:

    """

    :arg depth_slot:  
      GPUTexture to attach or a *dict* containing keywords: 'texture', 'layer' and 'mip'.

    :type depth_slot: 
      :class:`gpu.types.GPUTexture`, dict or Nonetype

    :arg color_slots: 
      Tuple where each item can be a GPUTexture or a *dict* containing keywords: 'texture', 'layer' and 'mip'.

    :type color_slots:
      tuple or Nonetype

    """

    ...

  def bind(self) -> None:

    """

    Context manager to ensure balanced bind calls, even in the case of an error.

    """

    ...

  def clear(self, color: typing.Sequence[typing.Any] = None, depth: float = None, stencil: int = None) -> None:

    """

    Fill color, depth and stencil textures with specific value.
Common values: color=(0.0, 0.0, 0.0, 1.0), depth=1.0, stencil=0.

    """

    ...

  def read_color(self, x: typing.Any, y: typing.Any, xsize: typing.Any, ysize: typing.Any, channels: int, slot: int, format: str, data: Buffer = data) -> Buffer:

    """

    Read a block of pixels from the frame buffer.

    """

    ...

  def read_depth(self, x: typing.Any, y: typing.Any, xsize: typing.Any, ysize: typing.Any, data: Buffer = data) -> Buffer:

    """

    Read a pixel depth block from the frame buffer.

    """

    ...

  def viewport_get(self) -> None:

    """

    Returns position and dimension to current viewport.

    """

    ...

  def viewport_set(self, x: typing.Any, y: typing.Any, xsize: typing.Any, ysize: typing.Any) -> None:

    """

    Set the viewport for this framebuffer object.
Note: The viewport state is not saved upon framebuffer rebind.

    """

    ...

  is_bound: typing.Any = ...

  """

  Checks if this is the active framebuffer in the context.

  """

class GPUIndexBuf:

  """

  Contains an index buffer.

  """

  def __init__(self, type: str, seq: typing.Any) -> None:

    """

    :arg type:        
      The primitive type this index buffer is composed of.
Possible values are *POINTS*, *LINES*, *TRIS* and *LINE_STRIP_ADJ*.

    :type type:       
      str

    :arg seq:         
      Indices this index buffer will contain.
Whether a 1D or 2D sequence is required depends on the type.
Optionally the sequence can support the buffer protocol.

    :type seq:        
      1D or 2D sequence

    """

    ...

class GPUOffScreen:

  """

  This object gives access to off screen buffers.

  """

  def __init__(self, width: int, height: int, *args, format: str = 'RGBA8') -> None:

    """

    :arg width:       
      Horizontal dimension of the buffer.

    :type width:      
      int

    :arg height:      
      Vertical dimension of the buffer.

    :type height:     
      int

    :arg format:      
      Internal data format inside GPU memory for color attachment texture. Possible values are:
*RGBA8*,
*RGBA16*,
*RGBA16F*,
*RGBA32F*,

    :type format:     
      str

    """

    ...

  def bind(self) -> None:

    """

    Context manager to ensure balanced bind calls, even in the case of an error.

    """

    ...

  def draw_view3d(self, scene: bpy.types.Scene, view_layer: bpy.types.ViewLayer, view3d: bpy.types.SpaceView3D, region: bpy.types.Region, view_matrix: mathutils.Matrix, projection_matrix: mathutils.Matrix, do_color_management: bool = False) -> None:

    """

    Draw the 3d viewport in the offscreen object.

    """

    ...

  def free(self) -> None:

    """

    Free the offscreen object.
The framebuffer, texture and render objects will no longer be accessible.

    """

    ...

  def unbind(self, restore: bool = True) -> None:

    """

    Unbind the offscreen object.

    """

    ...

  color_texture: int = ...

  """

  OpenGL bindcode for the color texture.

  """

  height: int = ...

  """

  Height of the texture.

  """

  texture_color: GPUTexture = ...

  """

  The color texture attached.

  """

  width: int = ...

  """

  Width of the texture.

  """

class GPUShader:

  """

  GPUShader combines multiple GLSL shaders into a program used for drawing.
It must contain at least a vertex and fragment shaders.

  The GLSL ``#version`` directive is automatically included at the top of shaders,
and set to 330. Some preprocessor directives are automatically added according to
the Operating System or availability: ``GPU_ATI``, ``GPU_NVIDIA`` and ``GPU_INTEL``.

  The following extensions are enabled by default if supported by the GPU:
``GL_ARB_texture_gather``, ``GL_ARB_texture_cube_map_array``
and ``GL_ARB_shader_draw_parameters``.

  For drawing user interface elements and gizmos, use
``fragOutput = blender_srgb_to_framebuffer_space(fragOutput)``
to transform the output sRGB colors to the frame-buffer color-space.

  """

  def __init__(self, vertexcode: str, fragcode: typing.Any, geocode: typing.Any = None, libcode: typing.Any = None, defines: typing.Any = None, name: typing.Any = 'pyGPUShader') -> None:

    """

    :arg vertexcode:  
      Vertex shader code.

    :type vertexcode: 
      str

    :arg fragcode:    
      Fragment shader code.

    :type value:      
      str

    :arg geocode:     
      Geometry shader code.

    :type value:      
      str

    :arg libcode:     
      Code with functions and presets to be shared between shaders.

    :type value:      
      str

    :arg defines:     
      Preprocessor directives.

    :type value:      
      str

    :arg name:        
      Name of shader code, for debugging purposes.

    :type value:      
      str

    """

    ...

  def attr_from_name(self, name: str) -> int:

    """

    Get attribute location by name.

    """

    ...

  def attrs_info_get(self) -> typing.Tuple[typing.Any, ...]:

    """

    Information about the attributes used in the Shader.

    """

    ...

  def bind(self) -> None:

    """

    Bind the shader object. Required to be able to change uniforms of this shader.

    """

    ...

  def format_calc(self) -> GPUVertFormat:

    """

    Build a new format based on the attributes of the shader.

    """

    ...

  def uniform_block(self, name: str, ubo: typing.Any) -> None:

    """

    Specify the value of an uniform buffer object variable for the current GPUShader.

    """

    ...

  def uniform_block_from_name(self, name: str) -> int:

    """

    Get uniform block location by name.

    """

    ...

  def uniform_bool(self, name: str, value: typing.Union[bool, typing.Sequence[bool]]) -> None:

    """

    Specify the value of a uniform variable for the current program object.

    """

    ...

  def uniform_float(self, name: str, value: typing.Any) -> None:

    """

    Specify the value of a uniform variable for the current program object.

    """

    ...

  def uniform_from_name(self, name: str) -> int:

    """

    Get uniform location by name.

    """

    ...

  def uniform_int(self, name: str, seq: typing.Sequence[typing.Any]) -> None:

    """

    Specify the value of a uniform variable for the current program object.

    """

    ...

  def uniform_sampler(self, name: str, texture: GPUTexture) -> None:

    """

    Specify the value of a texture uniform variable for the current GPUShader.

    """

    ...

  def uniform_vector_float(self, location: int, buffer: typing.Sequence[float], length: int, count: int) -> None:

    """

    Set the buffer to fill the uniform.

    """

    ...

  def uniform_vector_int(self, location: typing.Any, buffer: typing.Any, length: typing.Any, count: typing.Any) -> None:

    """

    See GPUShader.uniform_vector_float(...) description.

    """

    ...

  name: str = ...

  """

  The name of the shader object for debugging purposes (read-only).

  """

  program: int = ...

  """

  The name of the program object for use by the OpenGL API (read-only).

  """

class GPUShaderCreateInfo:

  """

  Stores and describes types and variables that are used in shader sources.

  .. code:: glsl

    #define name value

    :arg name: Token name.
    :type name: str
    :arg value: Text that replaces token occurrences.
    :type value: str

  .. code:: python

    "struct MyType {int foo; float bar;};"

    :arg source: The source code defining types.
    :type source: str

  """

  def define(self, name: typing.Any, value: typing.Any) -> None:

    """

    Add a preprocessing define directive. In GLSL it would be something like:

    """

    ...

  def fragment_out(self, slot: int, type: str, name: str, blend: str = 'NONE') -> None:

    """

    Specify a fragment output corresponding to a framebuffer target slot.

    """

    ...

  def fragment_source(self, source: str) -> None:

    """

    Fragment shader source code written in GLSL.

    Example:

    .. code:: python

      "void main {fragColor = vec4(0.0, 0.0, 0.0, 1.0);}"

    `GLSL Cross Compilation <https://wiki.blender.org/wiki/EEVEE_%26_Viewport/GPU_Module/GLSL_Cross_Compilation>`_

    """

    ...

  def push_constant(self, type: str, name: str, size: typing.Any = 0) -> None:

    """

    Specify a global access constant.

    """

    ...

  def sampler(self, slot: int, type: str, name: str) -> None:

    """

    Specify an image texture sampler.

    """

    ...

  def typedef_source(self, source: typing.Any) -> None:

    """

    Source code included before resource declaration. Useful for defining structs used by Uniform Buffers.

    Example:

    """

    ...

  def uniform_buf(self, slot: int, type_name: str, name: str) -> None:

    """

    Specify a uniform variable whose type can be one of those declared in *typedef_source*.

    """

    ...

  def vertex_in(self, slot: int, type: str, name: str) -> None:

    """

    Add a vertex shader input attribute.

    """

    ...

  def vertex_out(self, interface: GPUStageInterfaceInfo) -> None:

    """

    Add a vertex shader output interface block.

    """

    ...

  def vertex_source(self, source: str) -> None:

    """

    Vertex shader source code written in GLSL.

    Example:

    .. code:: python

      "void main {gl_Position = vec4(pos, 1.0);}"

    `GLSL Cross Compilation <https://wiki.blender.org/wiki/EEVEE_%26_Viewport/GPU_Module/GLSL_Cross_Compilation>`_

    """

    ...

class GPUStageInterfaceInfo:

  """

  List of varyings between shader stages.

  """

  def __init__(self, name: typing.Any) -> None:

    """

    :arg name:        
      Name of the interface block.

    :type value:      
      str

    """

    ...

  def flat(self, type: str, name: str) -> None:

    """

    Add an attribute with qualifier of type *flat* to the interface block.

    """

    ...

  def no_perspective(self, type: str, name: str) -> None:

    """

    Add an attribute with qualifier of type *no_perspective* to the interface block.

    """

    ...

  def smooth(self, type: str, name: str) -> None:

    """

    Add an attribute with qualifier of type *smooth* to the interface block.

    """

    ...

  name: str = ...

  """

  Name of the interface block.

  """

class GPUTexture:

  """

  This object gives access to off GPU textures.

  """

  def __init__(self, size: typing.Union[typing.Tuple[typing.Any, ...], int], layers: int = 0, is_cubemap: int = False, format: str = 'RGBA8', data: Buffer = None) -> None:

    """

    :arg size:        
      Dimensions of the texture 1D, 2D, 3D or cubemap.

    :type size:       
      tuple or int

    :arg layers:      
      Number of layers in texture array or number of cubemaps in cubemap array

    :type layers:     
      int

    :arg is_cubemap:  
      Indicates the creation of a cubemap texture.

    :type is_cubemap: 
      int

    :arg format:      
      Internal data format inside GPU memory. Possible values are:
*RGBA8UI*,
*RGBA8I*,
*RGBA8*,
*RGBA32UI*,
*RGBA32I*,
*RGBA32F*,
*RGBA16UI*,
*RGBA16I*,
*RGBA16F*,
*RGBA16*,
*RG8UI*,
*RG8I*,
*RG8*,
*RG32UI*,
*RG32I*,
*RG32F*,
*RG16UI*,
*RG16I*,
*RG16F*,
*RG16*,
*R8UI*,
*R8I*,
*R8*,
*R32UI*,
*R32I*,
*R32F*,
*R16UI*,
*R16I*,
*R16F*,
*R16*,
*R11F_G11F_B10F*,
*DEPTH32F_STENCIL8*,
*DEPTH24_STENCIL8*,
*SRGB8_A8*,
*RGB16F*,
*SRGB8_A8_DXT1*,
*SRGB8_A8_DXT3*,
*SRGB8_A8_DXT5*,
*RGBA8_DXT1*,
*RGBA8_DXT3*,
*RGBA8_DXT5*,
*DEPTH_COMPONENT32F*,
*DEPTH_COMPONENT24*,
*DEPTH_COMPONENT16*,

    :type format:     
      str

    :arg data:        
      Buffer object to fill the texture.

    :type data:       
      :class:`gpu.types.Buffer`

    """

    ...

  def clear(self, format: str = 'FLOAT', value: typing.Sequence[typing.Any] = (0.0, 0.0, 0.0, 1.0)) -> None:

    """

    Fill texture with specific value.

    """

    ...

  def read(self) -> None:

    """

    Creates a buffer with the value of all pixels.

    """

    ...

  format: str = ...

  """

  Format of the texture.

  """

  height: int = ...

  """

  Height of the texture.

  """

  width: int = ...

  """

  Width of the texture.

  """

class GPUUniformBuf:

  """

  This object gives access to off uniform buffers.

  """

  def __init__(self, data: bpy.types.Object) -> None:

    """

    :arg data:        
      Data to fill the buffer.

    :type data:       
      object exposing buffer interface

    """

    ...

  def update(self, data: typing.Any) -> None:

    """

    Update the data of the uniform buffer object.

    """

    ...

class GPUVertBuf:

  """

  Contains a VBO.

  """

  def __init__(self, format: GPUVertFormat, len: int) -> None:

    """

    :arg format:      
      Vertex format.

    :type format:     
      :class:`gpu.types.GPUVertFormat`

    :arg len:         
      Amount of vertices that will fit into this buffer.

    :type len:        
      int

    """

    ...

  def attr_fill(self, id: typing.Union[int, str], data: typing.Sequence[float]) -> None:

    """

    Insert data into the buffer for a single attribute.

    """

    ...

class GPUVertFormat:

  """

  This object contains information about the structure of a vertex buffer.

  """

  def attr_add(self, id: str, comp_type: str, len: int, fetch_mode: str) -> None:

    """

    Add a new attribute to the format.

    """

    ...



"""


Color Attribute Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:FLOAT_COLOR:     
  Color.

  RGBA color 32-bit floating-point values.

:BYTE_COLOR:      
  Byte Color.

  RGBA color with 8-bit positive integer values.

.. _rna-enum-color-attribute-type-items:

"""

import typing



"""


Import Mesh Operators
*********************

:func:`ply`

:func:`stl`

"""

import typing

def ply(filepath: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, hide_props_region: bool = True, directory: str = '', filter_glob: str = '*args.ply') -> None:

  """

  Load a PLY geometry file

  """

  ...

def stl(filepath: str = '', filter_glob: str = '*args.stl', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, directory: str = '', global_scale: float = 1.0, use_scene_unit: bool = False, use_facet_normal: bool = False, axis_forward: str = 'Y', axis_up: str = 'Z') -> None:

  """

  Load STL triangle mesh data

  """

  ...



"""


Export Anim Operators
*********************

:func:`bvh`

"""

import typing

def bvh(filepath: str = '', check_existing: bool = True, filter_glob: str = '*args.bvh', global_scale: float = 1.0, frame_start: int = 0, frame_end: int = 0, rotate_mode: str = 'NATIVE', root_transform_only: bool = False) -> None:

  """

  Save a BVH motion capture file from an armature

  """

  ...



"""


Dt Layers Select Dst Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:ACTIVE:          
  Active Layer.

  Affect active data layer of all targets.

:NAME:            
  By Name.

  Match target data layers to affect by name.

:INDEX:           
  By Order.

  Match target data layers to affect by order (indices).

.. _rna-enum-dt-layers-select-dst-items:

"""

import typing



"""


Rigidbody Constraint Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FIXED:           
  Fixed.

  Glue rigid bodies together.

:POINT:           
  Point.

  Constrain rigid bodies to move around common pivot point.

:HINGE:           
  Hinge.

  Restrict rigid body rotation to one axis.

:SLIDER:          
  Slider.

  Restrict rigid body translation to one axis.

:PISTON:          
  Piston.

  Restrict rigid body translation and rotation to one axis.

:GENERIC:         
  Generic.

  Restrict translation and rotation to specified axes.

:GENERIC_SPRING:  
  Generic Spring.

  Restrict translation and rotation to specified axes with springs.

:MOTOR:           
  Motor.

  Drive rigid body around or along an axis.

.. _rna-enum-rigidbody-constraint-type-items:

"""

import typing



"""


Attribute Domain Without Corner Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Attribute on point.

:EDGE:            
  Edge.

  Attribute on mesh edge.

:FACE:            
  Face.

  Attribute on mesh faces.

:CURVE:           
  Spline.

  Attribute on spline.

:INSTANCE:        
  Instance.

  Attribute on instance.

.. _rna-enum-attribute-domain-without-corner-items:

"""

import typing



"""


Motionpath Bake Location Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:HEADS:           
  Heads.

  Calculate bone paths from heads.

:TAILS:           
  Tails.

  Calculate bone paths from tails.

.. _rna-enum-motionpath-bake-location-items:

"""

import typing



"""


Subdivision Boundary Smooth Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:PRESERVE_CORNERS:
  Keep Corners.

  Smooth boundaries, but corners are kept sharp.

:ALL:             
  All.

  Smooth boundaries, including corners.

.. _rna-enum-subdivision-boundary-smooth-items:

"""

import typing



"""


Freestyle Chaining Iterators (freestyle.chainingiterators)
**********************************************************

This module contains chaining iterators used for the chaining
operation to construct long strokes by concatenating feature edges
according to selected chaining rules.  The module is also intended to
be a collection of examples for defining chaining iterators in Python.

:class:`ChainPredicateIterator`

:class:`ChainSilhouetteIterator`

:class:`pyChainSilhouetteIterator`

:class:`pyChainSilhouetteGenericIterator`

:class:`pyExternalContourChainingIterator`

:class:`pySketchyChainSilhouetteIterator`

:class:`pySketchyChainingIterator`

:class:`pyFillOcclusionsRelativeChainingIterator`

:class:`pyFillOcclusionsAbsoluteChainingIterator`

:class:`pyFillOcclusionsAbsoluteAndRelativeChainingIterator`

:class:`pyFillQi0AbsoluteAndRelativeChainingIterator`

:class:`pyNoIdChainSilhouetteIterator`

"""

import typing

import freestyle

class ChainPredicateIterator:

  """

  Class hierarchy: :class:`freestyle.types.Iterator` >
:class:`freestyle.types.ViewEdgeIterator` >
:class:`freestyle.types.ChainingIterator` >
:class:`ChainPredicateIterator`

  A "generic" user-controlled ViewEdge iterator.  This iterator is in
particular built from a unary predicate and a binary predicate.
First, the unary predicate is evaluated for all potential next
ViewEdges in order to only keep the ones respecting a certain
constraint.  Then, the binary predicate is evaluated on the current
ViewEdge together with each ViewEdge of the previous selection.  The
first ViewEdge respecting both the unary predicate and the binary
predicate is kept as the next one.  If none of the potential next
ViewEdge respects these two predicates, None is returned.

  """

  def __init__(self, upred: freestyle.types.UnaryPredicate1D, bpred: freestyle.types.BinaryPredicate1D, restrict_to_selection: bool = True, restrict_to_unvisited: bool = True, begin: freestyle.types.ViewEdge = None, orientation: bool = True) -> None:

    """

    Builds a ChainPredicateIterator from a unary predicate, a binary
predicate, a starting ViewEdge and its orientation or using the copy constructor.

    """

    ...

  def __init__(self, brother: ChainPredicateIterator) -> None:

    """

    Builds a ChainPredicateIterator from a unary predicate, a binary
predicate, a starting ViewEdge and its orientation or using the copy constructor.

    """

    ...

class ChainSilhouetteIterator:

  """

  Class hierarchy: :class:`freestyle.types.Iterator` >
:class:`freestyle.types.ViewEdgeIterator` >
:class:`freestyle.types.ChainingIterator` >
:class:`ChainSilhouetteIterator`

  A ViewEdge Iterator used to follow ViewEdges the most naturally.  For
example, it will follow visible ViewEdges of same nature.  As soon, as
the nature or the visibility changes, the iteration stops (by setting
the pointed ViewEdge to 0).  In the case of an iteration over a set of
ViewEdge that are both Silhouette and Crease, there will be a
precedence of the silhouette over the crease criterion.

  """

  def __init__(self, restrict_to_selection: bool = True, begin: freestyle.types.ViewEdge = None, orientation: bool = True) -> None:

    """

    Builds a ChainSilhouetteIterator from the first ViewEdge used for
iteration and its orientation or the copy constructor.

    """

    ...

  def __init__(self, brother: ChainSilhouetteIterator) -> None:

    """

    Builds a ChainSilhouetteIterator from the first ViewEdge used for
iteration and its orientation or the copy constructor.

    """

    ...

class pyChainSilhouetteIterator:

  """

  Natural chaining iterator that follows the edges of the same nature
following the topology of objects, with decreasing priority for
silhouettes, then borders, then suggestive contours, then all other edge
types.  A ViewEdge is only chained once.

  """

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pyChainSilhouetteGenericIterator:

  """

  Natural chaining iterator that follows the edges of the same nature
following the topology of objects, with decreasing priority for
silhouettes, then borders, then suggestive contours, then all other
edge types.

  """

  def __init__(self, stayInSelection: bool = True, stayInUnvisited: bool = True) -> None:

    """

    Builds a pyChainSilhouetteGenericIterator object.

    """

    ...

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pyExternalContourChainingIterator:

  """

  Chains by external contour

  """

  def checkViewEdge(self, ve: typing.Any, orientation: typing.Any) -> None:

    ...

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pySketchyChainSilhouetteIterator:

  """

  Natural chaining iterator with a sketchy multiple touch.  It chains the
same ViewEdge multiple times to achieve a sketchy effect.

  """

  def __init__(self, nRounds: int = 3, stayInSelection: bool = True) -> None:

    """

    Builds a pySketchyChainSilhouetteIterator object.

    """

    ...

  def init(self) -> None:

    ...

  def make_sketchy(self, ve: typing.Any) -> None:

    """

    Creates the skeychy effect by causing the chain to run from
the start again. (loop over itself again)

    """

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pySketchyChainingIterator:

  """

  Chaining iterator designed for sketchy style. It chains the same
ViewEdge several times in order to produce multiple strokes per
ViewEdge.

  """

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pyFillOcclusionsRelativeChainingIterator:

  """

  Chaining iterator that fills small occlusions

  """

  def __init__(self, percent: float) -> None:

    """

    Builds a pyFillOcclusionsRelativeChainingIterator object.

    """

    ...

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pyFillOcclusionsAbsoluteChainingIterator:

  """

  Chaining iterator that fills small occlusions

  """

  def __init__(self, length: int) -> None:

    """

    Builds a pyFillOcclusionsAbsoluteChainingIterator object.

    """

    ...

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pyFillOcclusionsAbsoluteAndRelativeChainingIterator:

  """

  Chaining iterator that fills small occlusions regardless of the
selection.

  """

  def __init__(self, percent: float, l: float) -> None:

    """

    Builds a pyFillOcclusionsAbsoluteAndRelativeChainingIterator object.

    """

    ...

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pyFillQi0AbsoluteAndRelativeChainingIterator:

  """

  Chaining iterator that fills small occlusions regardless of the
selection.

  """

  def __init__(self, percent: float, l: float) -> None:

    """

    Builds a pyFillQi0AbsoluteAndRelativeChainingIterator object.

    """

    ...

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...

class pyNoIdChainSilhouetteIterator:

  """

  Natural chaining iterator that follows the edges of the same nature
following the topology of objects, with decreasing priority for
silhouettes, then borders, then suggestive contours, then all other edge
types.  It won't chain the same ViewEdge twice.

  """

  def __init__(self, stayInSelection: bool = True) -> None:

    """

    Builds a pyNoIdChainSilhouetteIterator object.

    """

    ...

  def init(self) -> None:

    ...

  def traverse(self, iter: typing.Any) -> None:

    ...



"""


Property Unit Items
^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:LENGTH:          
  Length.

:AREA:            
  Area.

:VOLUME:          
  Volume.

:ROTATION:        
  Rotation.

:TIME:            
  Time (Scene Relative).

:TIME_ABSOLUTE:   
  Time (Absolute).

:VELOCITY:        
  Velocity.

:ACCELERATION:    
  Acceleration.

:MASS:            
  Mass.

:CAMERA:          
  Camera.

:POWER:           
  Power.

:TEMPERATURE:     
  Temperature.

.. _rna-enum-property-unit-items:

"""

import typing



"""


bpy_extras submodule (bpy_extras.asset_utils)
*********************************************

Helpers for asset management tasks.

:class:`SpaceAssetInfo`

"""

import typing

class SpaceAssetInfo:

  ...



"""


Property Flag Enum Items
^^^^^^^^^^^^^^^^^^^^^^^^

:HIDDEN:          
  Hidden.

:SKIP_SAVE:       
  Skip Save.

:ANIMATABLE:      
  Animatable.

:LIBRARY_EDITABLE:
  Library Editable.

:ENUM_FLAG:       
  Enum Flag.

.. _rna-enum-property-flag-enum-items:

"""

import typing



"""


Image Generated Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:BLANK:           
  Blank.

  Generate a blank image.

:UV_GRID:         
  UV Grid.

  Generated grid to test UV mappings.

:COLOR_GRID:      
  Color Grid.

  Generated improved UV grid to test UV mappings.

.. _rna-enum-image-generated-type-items:

"""

import typing



"""


Linestyle Geometry Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:2D_OFFSET:       
  2D Offset.

:2D_TRANSFORM:    
  2D Transform.

:BACKBONE_STRETCHER:
  Backbone Stretcher.

:BEZIER_CURVE:    
  Bezier Curve.

:BLUEPRINT:       
  Blueprint.

:GUIDING_LINES:   
  Guiding Lines.

:PERLIN_NOISE_1D: 
  Perlin Noise 1D.

:PERLIN_NOISE_2D: 
  Perlin Noise 2D.

:POLYGONIZATION:  
  Polygonization.

:SAMPLING:        
  Sampling.

:SIMPLIFICATION:  
  Simplification.

:SINUS_DISPLACEMENT:
  Sinus Displacement.

:SPATIAL_NOISE:   
  Spatial Noise.

:TIP_REMOVER:     
  Tip Remover.

.. _rna-enum-linestyle-geometry-modifier-type-items:

"""

import typing



"""


Uv Operators
************

:func:`align`

:func:`align_rotation`

:func:`average_islands_scale`

:func:`copy`

:func:`cube_project`

:func:`cursor_set`

:func:`cylinder_project`

:func:`export_layout`

:func:`follow_active_quads`

:func:`hide`

:func:`lightmap_pack`

:func:`mark_seam`

:func:`minimize_stretch`

:func:`pack_islands`

:func:`paste`

:func:`pin`

:func:`project_from_view`

:func:`randomize_uv_transform`

:func:`remove_doubles`

:func:`reset`

:func:`reveal`

:func:`rip`

:func:`rip_move`

:func:`seams_from_islands`

:func:`select`

:func:`select_all`

:func:`select_box`

:func:`select_circle`

:func:`select_edge_ring`

:func:`select_lasso`

:func:`select_less`

:func:`select_linked`

:func:`select_linked_pick`

:func:`select_loop`

:func:`select_mode`

:func:`select_more`

:func:`select_overlap`

:func:`select_pinned`

:func:`select_similar`

:func:`select_split`

:func:`shortest_path_pick`

:func:`shortest_path_select`

:func:`smart_project`

:func:`snap_cursor`

:func:`snap_selected`

:func:`sphere_project`

:func:`stitch`

:func:`unwrap`

:func:`weld`

"""

import typing

import mathutils

def align(axis: str = 'ALIGN_AUTO') -> None:

  """

  Align selected UV vertices to an axis

  """

  ...

def align_rotation(method: str = 'AUTO', axis: str = 'X') -> None:

  """

  Align uv island's rotation

  """

  ...

def average_islands_scale(scale_uv: bool = False, shear: bool = False) -> None:

  """

  Average the size of separate UV islands, based on their area in 3D space

  """

  ...

def copy() -> None:

  """

  Copy selected UV vertices

  """

  ...

def cube_project(cube_size: float = 1.0, correct_aspect: bool = True, clip_to_bounds: bool = False, scale_to_bounds: bool = False) -> None:

  """

  Project the UV vertices of the mesh over the six faces of a cube

  """

  ...

def cursor_set(location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Set 2D cursor location

  """

  ...

def cylinder_project(direction: str = 'VIEW_ON_EQUATOR', align: str = 'POLAR_ZX', pole: str = 'PINCH', radius: float = 1.0, correct_aspect: bool = True, clip_to_bounds: bool = False, scale_to_bounds: bool = False) -> None:

  """

  Project the UV vertices of the mesh over the curved wall of a cylinder

  """

  ...

def export_layout(filepath: str = '', export_all: bool = False, modified: bool = False, mode: str = 'PNG', size: typing.Tuple[int, int] = (1024, 1024), opacity: float = 0.25, check_existing: bool = True) -> None:

  """

  Export UV layout to file

  """

  ...

def follow_active_quads(mode: str = 'LENGTH_AVERAGE') -> None:

  """

  Follow UVs from active quads along continuous face loops

  """

  ...

def hide(unselected: bool = False) -> None:

  """

  Hide (un)selected UV vertices

  """

  ...

def lightmap_pack(PREF_CONTEXT: str = 'SEL_FACES', PREF_PACK_IN_ONE: bool = True, PREF_NEW_UVLAYER: bool = False, PREF_APPLY_IMAGE: bool = False, PREF_IMG_PX_SIZE: int = 512, PREF_BOX_DIV: int = 12, PREF_MARGIN_DIV: float = 0.1) -> None:

  """

  Pack each face's UVs into the UV bounds

  """

  ...

def mark_seam(clear: bool = False) -> None:

  """

  Mark selected UV edges as seams

  """

  ...

def minimize_stretch(fill_holes: bool = True, blend: float = 0.0, iterations: int = 0) -> None:

  """

  Reduce UV stretching by relaxing angles

  """

  ...

def pack_islands(udim_source: str = 'CLOSEST_UDIM', rotate: bool = True, margin_method: str = 'SCALED', margin: float = 0.001) -> None:

  """

  Transform all islands so that they fill up the UV/UDIM space as much as possible

  """

  ...

def paste() -> None:

  """

  Paste selected UV vertices

  """

  ...

def pin(clear: bool = False) -> None:

  """

  Set/clear selected UV vertices as anchored between multiple unwrap operations

  """

  ...

def project_from_view(orthographic: bool = False, camera_bounds: bool = True, correct_aspect: bool = True, clip_to_bounds: bool = False, scale_to_bounds: bool = False) -> None:

  """

  Project the UV vertices of the mesh as seen in current 3D view

  """

  ...

def randomize_uv_transform(random_seed: int = 0, use_loc: bool = True, loc: mathutils.Vector = (0.0, 0.0), use_rot: bool = True, rot: float = 0.0, use_scale: bool = True, scale_even: bool = False, scale: typing.Tuple[float, float] = (1.0, 1.0)) -> None:

  """

  Randomize uv island's location, rotation, and scale

  """

  ...

def remove_doubles(threshold: float = 0.02, use_unselected: bool = False) -> None:

  """

  Selected UV vertices that are within a radius of each other are welded together

  """

  ...

def reset() -> None:

  """

  Reset UV projection

  """

  ...

def reveal(select: bool = True) -> None:

  """

  Reveal all hidden UV vertices

  """

  ...

def rip(mirror: bool = False, release_confirm: bool = False, use_accurate: bool = False, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Rip selected vertices or a selected region

  """

  ...

def rip_move(UV_OT_rip: UV_OT_rip = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Unstitch UVs and move the result

  """

  ...

def seams_from_islands(mark_seams: bool = True, mark_sharp: bool = False) -> None:

  """

  Set mesh seams according to island setup in the UV editor

  """

  ...

def select(extend: bool = False, deselect: bool = False, toggle: bool = False, deselect_all: bool = False, select_passthrough: bool = False, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Select UV vertices

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  Change selection of all UV vertices

  """

  ...

def select_box(pinned: bool = False, xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select UV vertices using box selection

  """

  ...

def select_circle(x: int = 0, y: int = 0, radius: int = 25, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select UV vertices using circle selection

  """

  ...

def select_edge_ring(extend: bool = False, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Select an edge ring of connected UV vertices

  """

  ...

def select_lasso(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, mode: str = 'SET') -> None:

  """

  Select UVs using lasso selection

  """

  ...

def select_less() -> None:

  """

  Deselect UV vertices at the boundary of each selection region

  """

  ...

def select_linked() -> None:

  """

  Select all UV vertices linked to the active UV map

  """

  ...

def select_linked_pick(extend: bool = False, deselect: bool = False, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Select all UV vertices linked under the mouse

  """

  ...

def select_loop(extend: bool = False, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Select a loop of connected UV vertices

  """

  ...

def select_mode(type: str = 'VERTEX') -> None:

  """

  Change UV selection mode

  """

  ...

def select_more() -> None:

  """

  Select more UV vertices connected to initial selection

  """

  ...

def select_overlap(extend: bool = False) -> None:

  """

  Select all UV faces which overlap each other

  """

  ...

def select_pinned() -> None:

  """

  Select all pinned UV vertices

  """

  ...

def select_similar(type: str = 'PIN', compare: str = 'EQUAL', threshold: float = 0.0) -> None:

  """

  Select similar UVs by property types

  """

  ...

def select_split() -> None:

  """

  Select only entirely selected faces

  """

  ...

def shortest_path_pick(use_face_step: bool = False, use_topology_distance: bool = False, use_fill: bool = False, skip: int = 0, nth: int = 1, offset: int = 0, object_index: int = -1, index: int = -1) -> None:

  """

  Select shortest path between two selections

  """

  ...

def shortest_path_select(use_face_step: bool = False, use_topology_distance: bool = False, use_fill: bool = False, skip: int = 0, nth: int = 1, offset: int = 0) -> None:

  """

  Selected shortest path between two vertices/edges/faces

  """

  ...

def smart_project(angle_limit: float = 1.15192, margin_method: str = 'SCALED', island_margin: float = 0.0, area_weight: float = 0.0, correct_aspect: bool = True, scale_to_bounds: bool = False) -> None:

  """

  Projection unwraps the selected faces of mesh objects

  """

  ...

def snap_cursor(target: str = 'PIXELS') -> None:

  """

  Snap cursor to target type

  """

  ...

def snap_selected(target: str = 'PIXELS') -> None:

  """

  Snap selected UV vertices to target type

  """

  ...

def sphere_project(direction: str = 'VIEW_ON_EQUATOR', align: str = 'POLAR_ZX', pole: str = 'PINCH', correct_aspect: bool = True, clip_to_bounds: bool = False, scale_to_bounds: bool = False) -> None:

  """

  Project the UV vertices of the mesh over the curved surface of a sphere

  """

  ...

def stitch(use_limit: bool = False, snap_islands: bool = True, limit: float = 0.01, static_island: int = 0, active_object_index: int = 0, midpoint_snap: bool = False, clear_seams: bool = True, mode: str = 'VERTEX', stored_mode: str = 'VERTEX', selection: typing.Union[typing.Sequence[SelectedUvElement], typing.Mapping[str, SelectedUvElement], bpy.types.bpy_prop_collection] = None, objects_selection_count: typing.Tuple[int, ...] = (0, 0, 0, 0, 0, 0)) -> None:

  """

  Stitch selected UV vertices by proximity

  """

  ...

def unwrap(method: str = 'ANGLE_BASED', fill_holes: bool = True, correct_aspect: bool = True, use_subsurf_data: bool = False, margin_method: str = 'SCALED', margin: float = 0.001) -> None:

  """

  Unwrap the mesh of the object being edited

  """

  ...

def weld() -> None:

  """

  Weld selected UV vertices together

  """

  ...
